import 'package:feed_plugin_example/localization/gettext.dart';
import 'package:feed_plugin_example/localization/parser.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart' show rootBundle;


class PhonedoLocalizations {
  final Gettext gt;

  PhonedoLocalizations(this.gt);

  static PhonedoLocalizations of(BuildContext context) {
    return Localizations.of<PhonedoLocalizations>(
        context, PhonedoLocalizations);
  }

  String get locale => gt.locale;

  bool  get isSupportedLocale => ['en', 'ru', 'he'].contains(gt.locale);

  String translate(String value, {String domain='messages', Map<String, String> msgctxt}) {

    var res = gt.gettext(value, domain: domain);
    if(msgctxt!=null){//manual interpolation. It should be evaluated via Gettext::msgctxt, but I didn't know how
      msgctxt.forEach((k,v) {
        res = res.replaceFirst(['{',k,'}'].join(), v);
      });
    }
    return res.replaceAll(r'\\', r'\');
  }
}

class PhonedoLocalizationsDelegate extends LocalizationsDelegate<PhonedoLocalizations> {

  @override
  bool isSupported(Locale locale) => ['en', 'ru', 'he'].contains(locale.languageCode);

  @override
  Future<PhonedoLocalizations> load(Locale locale) async {
    var data = await rootBundle.loadString('images/${locale.languageCode}.po');
    data ??= await rootBundle.loadString('images/en.po');
    Map translateTable = PoParser(data).parse();
    final gt =  Gettext();
    gt.locale = locale.languageCode;
    gt.addLocale(translateTable);
    return PhonedoLocalizations(gt);
  }

  @override
  bool shouldReload(PhonedoLocalizationsDelegate old) => false;
}