import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'feed_state.dart';

class FeedCubit extends Cubit<FeedState> {
  final FeedRepository feedRepository;

  FeedCubit({
    this.feedRepository,
  }) : super(FeedInitialState());

  Future<void> fetchPartnerInfo(
      firstName, profileImg, token, socialMedia) async {
    var currentState = state;
    var user = currentState is FeedReadyState ? currentState.currentUser : null;

    emit(FeedInitialState());
    try {
      await feedRepository
          .authenticateUser(
              firstName: firstName,
              lastName: "",
              about: "",
              profileImg: profileImg,
              token: token,
              socialMedia: socialMedia,
              partnerId: null)
          .then((partner) =>
              emit(FeedReadyState(currentPartner: partner, currentUser: user)));
    } catch (e) {
      print('getPartnerUser failed error: ' + e);
      emit(FeedErrorState(error: 'Internal server error, please try later'));
    }
  }

  Future<void> fetchUserInfo(
      firstName, lastName, about, profileImg, token) async {
    var currentState = state;
    var partner =
        currentState is FeedReadyState ? currentState.currentPartner : null;

    emit(FeedInitialState());
    try {
      await feedRepository
          .authenticateUser(
              firstName: firstName,
              lastName: lastName,
              about: about,
              profileImg: profileImg,
              token: token,
              socialMedia: null,
              partnerId: null)
          .then((user) =>
              emit(FeedReadyState(currentPartner: partner, currentUser: user)));
    } catch (e) {
      print('getUser failed error: ' + e);
      emit(FeedErrorState(error: 'Internal server error, please try later'));
    }
  }

  Future<void> fetchPartnerAndUserData(partner, user) async {
    emit(FeedInitialState());
    try {
      emit(FeedReadyState(currentPartner: partner, currentUser: user));
    } catch (e) {
      print('getUser failed error: ' + e);
      emit(FeedErrorState(error: 'Internal server error, please try later'));
    }
  }
}
