import 'dart:convert';
import 'package:feed_plugin/environment_config.dart';
import 'package:feed_plugin/feed_plugin.dart';
import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/models/post_comment_model.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/replyCommentModel.dart';
import 'package:feed_plugin/models/poll_option_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/pages/comments/widgets/message_reply.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:feed_plugin/widgets/post.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:flutter_screenutil/screen_util.dart';
import 'package:pusher_client/pusher_client.dart';

import '../widgets/messages_item.dart';

class ChatScreen extends StatefulWidget {
  final String senderName;
  final String about;
  final String senderImage;
  final FeedPost post;
  final UserModel currentUser;
  final List<PostModel> postsList;
  final List<PollOptionModel> pollOptionsList;
  final List<PollVoteModel> pollVotesList;

  final loc;

  const ChatScreen({
    @required this.senderName,
    @required this.about,
    @required this.senderImage,
    @required this.post,
    @required this.currentUser,
    @required this.postsList,
    @required this.pollOptionsList,
    @required this.pollVotesList,
    @required this.loc,
  });

  @override
  _ChatScreenState createState() => _ChatScreenState();
}

class _ChatScreenState extends State<ChatScreen> {
  double defaultScreenWidth = 375.0;
  double defaultScreenHeight = 812.0;
  FocusNode focusNode;
  bool isChatBuild;
  int reply_flag = -1;
  int indexL = 0;
  List<ReplyCommentModel> list = [];

  List<PostCommentModel> commentsList;
  List<ReplyCommentModel> replyCommentsList;
  List<Widget> replyWidgets1;
  List<List<Widget>> replyWidgets;

  List<PollOptionModel> pollOptionsListToPost;

  Future<UserModel> getUserById(id) async {
    UserModel user = await feedRepository.fetchUserData(id);
    return user;
  }

  ScrollController _scrollController;
  HttpService httpService;
  FeedRepository feedRepository;
  // PusherClient pusher;

  Channel _channelComment;
  TextEditingController _textEditingController;

  int commentsLength;

  @override
  void initState() {
    commentsLength = 0;
    _textEditingController = TextEditingController();
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    super.initState();
    focusNode = FocusNode();
    commentsList = [];
    replyCommentsList = [];
    replyWidgets = [];
    indexL = 0;
    reply_flag = -1;
    loadData();
    _initPusher();
    _scrollController = ScrollController();

    if (widget.post.postData.pollQuestion != null) {
      pollOptionsListToPost = widget.pollOptionsList
          .where(
              (p) => p.pollQuestion.id == widget.post.postData.pollQuestion.id)
          .toList();
    }
  }

  @override
  void dispose() {
    _scrollController.dispose();
    _textEditingController.dispose();
    focusNode.dispose();
    super.dispose();
  }

  Future<List<PostCommentModel>> getCommentsList() async {
    commentsList =
        await feedRepository.fetchPostComments(this.widget.post.postData.id);
    return commentsList;
  }

  Future<List<ReplyCommentModel>> getReplayCommentsList() async {
    replyCommentsList = await feedRepository.getReplayCommentsList();
    return replyCommentsList;
  }

  loadData() async {
    List<ReplyCommentModel> reply = [];
    await getCommentsList().then(
      (data) {
        setState(
          () {
            commentsList = data;
            commentsLength = data.length;
          },
        );
        getReplayCommentsList().then((replyC) async => {
              if (replyC != null)
                {
                  reply = replyC
                      .where((item) =>
                          item.postComments.post.id == widget.post.postData.id)
                      .toList(),
                },
              setState(
                () {
                  replyCommentsList = reply;
                  commentsLength += reply.length;
                },
              ),
              await data.forEach((c) async {
                replyWidgets1 = [];
                if (replyCommentsList != null) {
                  for (var i = 0; i < replyCommentsList.length + 1; i++) {
                    if (i == replyCommentsList.length) {
                      if (replyWidgets1.length > 0) {
                        replyWidgets.add(replyWidgets1);
                      } else {
                        replyWidgets.add(null);
                      }
                    } else {
                      var l = replyCommentsList[i];
                      if (l.postComments.id == c.id) {
                        var w = MessagesReply(
                          replyCommentModel: l,
                          isUserMassage:
                              l.user.id == widget.currentUser.id ? true : false,
                          commentId: l.id,
                          loc: this.widget.loc,
                        );
                        replyWidgets1.add(w);
                      }
                    }
                  }
                }
              })
            });
      },
    );
  }

  Future<void> _initPusher() async {
    // pusher = PusherClient(
    //   EnvironmentConfig.PUSHER_ENV,
    //   PusherOptions(
    //     cluster: "ap2",
    //   ),
    //   autoConnect: false,
    // );
    _channelComment = FeedPlugin.pusher.subscribe('comment');

    _channelComment.bind('create_comment', (onEvent) {
      List<dynamic> newComment = json.decode(onEvent.data);
      List<PostCommentModel> comments =
          newComment.map((i) => PostCommentModel.fromJson(i)).toList();
      if (mounted) {
        this.setState(() {
          if (comments[0].post.id == this.widget.post.postData.id) {
            commentsList.add(comments[0]);
            commentsLength += 1;
            replyWidgets.add(null);
          }
        });
      }
    });

    _channelComment.bind('remove_comment', (onEvent) {
      int id = int.parse(onEvent.data);
      int index1;
      List<PostCommentModel> comments = [];
      for (var i = 0; i < commentsList.length; i++) {
        if (commentsList[i].id == id) {
          index1 = i;
        } else {
          comments.add(commentsList[i]);
        }
      }
      if (mounted) {
        this.setState(() {
          commentsList = comments;
          commentsLength = comments.length == 0
              ? -1
              : replyWidgets[index1] != null
                  ? commentsLength - 1 - replyWidgets[index1].length
                  : commentsLength - 1;
          replyWidgets.removeAt(index1);
        });
      }
    });

    _channelComment.bind('remove_reply_comment', (onEvent) {
      int id = int.parse(onEvent.data);
      int index1;
      int index2 = -1;
      List<ReplyCommentModel> comments = [];
      PostCommentModel postComment;
      int j = -1;

      comments = replyCommentsList.where((r) => r.id != id).toList();

      postComment =
          replyCommentsList.where((r) => r.id == id).first.postComments;

      for (var a = 0; a < commentsList.length; a++) {
        if (commentsList[a].id == postComment.id) {
          index1 = a;
          break;
        }
      }

      for (var b = 0; b < replyCommentsList.length; b++) {
        if (replyCommentsList[b].postComments.id == postComment.id) {
          j++;
          if (replyCommentsList[b].id == id) {
            index2 = j;
            break;
          }
        }
      }
      if (mounted) {
        this.setState(() {
          replyCommentsList = comments;
          replyWidgets[index1].removeAt(index2);
        });
      }
    });

    _channelComment.bind('create_reply_comment', (onEvent) {
      List<dynamic> newComment = json.decode(onEvent.data);
      List<ReplyCommentModel> comments =
          newComment.map((i) => ReplyCommentModel.fromJson(i)).toList();
      if (comments[0].postComments.post.id == this.widget.post.postData.id) {
        for (var i = 0; i < commentsList.length; i++) {
          if (commentsList[i].id == comments[0].postComments.id) {
            var w = MessagesReply(
              replyCommentModel: comments[0],
              isUserMassage:
                  comments[0].user.id == widget.currentUser.id ? true : false,
              commentId: comments[0].id,
              loc: this.widget.loc,
            );
            setState(() {
              replyCommentsList.add(comments[0]);
              if (replyWidgets != null) {
                if (replyWidgets[i] != null) {
                  replyWidgets[i].add(w);
                } else {
                  replyWidgets[i] = [];
                  replyWidgets[i].add(w);
                }
              }
              reply_flag = -1;
            });
            break;
          }
        }
      }
    });
  }

  void _sendMessage() {
    if (_textEditingController.text.isEmpty) return;
    reply_flag != -1
        ? feedRepository
            .addReplyComment(
                reply_flag, widget.currentUser.id, _textEditingController.text)
            .then((value) => {
                  setState(() => {reply_flag = -1})
                })
        : HttpService("jhgvf").uploadComment(
            userId: this.widget.currentUser.id,
            postId: this.widget.post.postData.id,
            comment: _textEditingController.text);
    focusNode.unfocus();

    setState(() {
      _textEditingController.text = "";
    });
  }

  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
      textDirection: TextDirection.ltr,
      child: ScreenUtilInit(
        designSize: Size(width, height),
        allowFontScaling: true,
        builder: () => Scaffold(
            appBar: PreferredSize(
              preferredSize: Size.fromHeight(70.0),
              child: AppBar(
                backgroundColor: Color(0xFF083356),
                leading: _buildLeading(),
              ),
            ),
            backgroundColor: Colors.white,
            body: _buildBody()),
      ),
    );
  }

  _buildLeading() {
    return Padding(
      padding: EdgeInsets.only(
        top: ScreenUtil().setWidth(9),
      ),
      child: IconButton(
        onPressed: () {
          FeedPost thisPost = FeedPost(
            loc: this.widget.loc,
            postData: this.widget.post.postData,
            currentUser: this.widget.post.currentUser,
            likeId: this.widget.post.likeId,
            dislikeId: this.widget.post.dislikeId,
            saveId: this.widget.post.saveId,
            images: this.widget.post.images,
            commentsLength: commentsLength,
            postsList: this.widget.postsList,
            pollOptionsList: pollOptionsListToPost,
            generalPollOptionsList: this.widget.pollOptionsList,
            pollVotesList: widget.post.postData.pollQuestion != null
                ? this
                    .widget
                    .pollVotesList
                    .where((p) =>
                        p.pollOption.pollQuestion.id ==
                        this.widget.post.postData.pollQuestion.id)
                    .toList()
                : null,
          );
          Navigator.pop(context, thisPost);
        },
        icon: Icon(Icons.arrow_back, color: Colors.white),
      ),
    );
  }

  _buildBody() {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Expanded(
          child: ListView(
            children: [
              _buildPost(),
              Divider(
                color: Color(0xffE8ECEF),
              ),
              _buildTitle(),
              _buildListComments(),
            ],
          ),
        ),
        _buildInputComment()
      ],
    );
  }

  _buildPost() {
    return FeedPost(
      postData: this.widget.post.postData,
      currentUser: this.widget.post.currentUser,
      likeId: this.widget.post.likeId,
      dislikeId: this.widget.post.dislikeId,
      saveId: this.widget.post.saveId,
      images: this.widget.post.images,
      commentsLength: commentsLength,
      postsList: this.widget.postsList,
      pollOptionsList: widget.post.postData.pollQuestion != null
          ? pollOptionsListToPost
          : null,
      generalPollOptionsList: widget.post.postData.pollQuestion != null
          ? this.widget.pollOptionsList
          : null,
      pollVotesList: widget.post.postData.pollQuestion != null
          ? widget.pollVotesList
              .where((p) =>
                  p.pollOption.pollQuestion.id ==
                  this.widget.post.postData.pollQuestion.id)
              .toList()
          : null,
      loc: this.widget.loc,
    );
  }

  _buildTitle() {
    return Padding(
      padding: EdgeInsets.only(
        left: ScreenUtil().setWidth(16),
        top: ScreenUtil().setWidth(20),
        bottom: ScreenUtil().setWidth(30),
      ),
      child: Container(
        child: Text(
          this.widget.loc.translate('Comments'),
          style: TextStyle(
            fontWeight: FontWeight.w500,
            color: Colors.black,
            fontSize: ScreenUtil().setSp(16),
            fontFamily: 'Rubik',
          ),
        ),
      ),
    );
  }

  _buildListComments() {
    return Container(
        child: ListView.builder(
            shrinkWrap: true,
            reverse: true,
            physics: ClampingScrollPhysics(),
            controller: _scrollController,
            itemCount: commentsList != null ? commentsList.length : 0,
            itemBuilder: (BuildContext ctx, int index) {
              PostCommentModel comment = commentsList[index];

              return comment.post.id == this.widget.post.postData.id
                  ? Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        MessagesItem(
                          postCommentModel: comment,
                          isUserMassage:
                              comment.user.id == this.widget.currentUser.id
                                  ? true
                                  : false,
                          commentId: comment.id,
                          loc: this.widget.loc,
                        ),
                        GestureDetector(
                            onTap: () => {
                                  setState(() => {
                                        focusNode.requestFocus(),
                                        reply_flag = comment.id
                                      }),
                                },
                            child: Container(
                              margin: EdgeInsets.only(
                                  bottom: ScreenUtil().setHeight(5),
                                  left: ScreenUtil().setWidth(67)),
                              child: Text(
                                widget.loc.translate("Reply"),
                                style: TextStyle(color: Colors.blue),
                              ),
                            )),
                        Container(
                          margin: EdgeInsets.only(
                            left: ScreenUtil().setWidth(40),
                            bottom: ScreenUtil().setWidth(5),
                          ),
                          child: Column(
                              children: replyWidgets.length == 0
                                  ? [Container()]
                                  : replyWidgets[index] == null
                                      ? [Container()]
                                      : replyWidgets[index]),
                        )
                      ],
                    )
                  : Container();
            }));
  }

  _buildInputComment() {
    return Container(
      decoration: BoxDecoration(
        color: Colors.white,
        boxShadow: <BoxShadow>[
          BoxShadow(
            color: Colors.grey[300],
            offset: new Offset(5.0, 5.0),
            blurRadius: 20.0,
          )
        ],
      ),
      child: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 10, vertical: 5),
        child: Row(
          children: <Widget>[
            Padding(
              padding: EdgeInsets.only(
                left: ScreenUtil().setWidth(16),
                right: ScreenUtil().setWidth(8),
              ),
              child: this.widget.currentUser.profileImg == null ||
                      this.widget.currentUser.profileImg == "" ||
                      this.widget.currentUser.profileImg == "null"
                  ? DefaultProfileImg(
                      firstName: this.widget.currentUser.firstName,
                      lastName: this.widget.currentUser.lastName)
                  : ClipOval(
                      child: Image.network(
                        this.widget.currentUser.profileImg,
                        width: ScreenUtil().setWidth(38),
                        height: ScreenUtil().setWidth(39),
                        fit: BoxFit.cover,
                      ),
                    ),
            ),
            Expanded(
              child: Theme(
                data:
                    Theme.of(context).copyWith(splashColor: Colors.transparent),
                child: TextField(
                  focusNode: focusNode,
                  maxLength: 1000,
                  keyboardType: TextInputType.multiline,
                  maxLines: null,
                  maxLengthEnforcement: MaxLengthEnforcement.enforced,
                  onSubmitted: (_) {
                    _sendMessage();
                  },
                  controller: _textEditingController,
                  decoration: InputDecoration(
                    contentPadding: const EdgeInsets.symmetric(
                        vertical: 1.0, horizontal: 10),
                    hintText: this.widget.loc.translate('Type your comment...'),
                    hintStyle: TextStyle(
                      fontSize: ScreenUtil().setSp(14),
                      color: Color(0xff98A9BC),
                    ),
                    alignLabelWithHint: true,
                    filled: true,
                    fillColor: Color(0xffF5F5F5),
                    counterText: "",
                    border: OutlineInputBorder(
                      borderSide: BorderSide(
                        color: Colors.grey,
                      ),
                      borderRadius: BorderRadius.circular(30),
                    ),
                  ),
                ),
              ),
            ),
            Container(
              padding: const EdgeInsets.only(left: 10),
              child: ClipOval(
                  child: Material(
                color: Color(0xFF3DD598),
                child: InkWell(
                  splashColor: Color(0xFFFCA64F),
                  child: IconButton(
                    onPressed: _sendMessage,
                    icon: Icon(Icons.send_rounded),
                    color: Colors.white,
                    iconSize: 30,
                  ),
                ),
              )),
            ),
          ],
        ),
      ),
    );
  }
}
