import 'package:feed_plugin/models/hashtagPostsModel.dart';
import 'package:feed_plugin/models/poll_option_model.dart';
import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/widgets/post.dart';

class HashtagPosts extends StatefulWidget {
  const HashtagPosts({
    Key key,
    @required this.hashtagPostsData,
    @required this.currentUser,
    @required this.pollOptionsList,
    @required this.pollVotesList,
    @required this.loc,
  }) : super(key: key);

  final List<HashtagPostsModel> hashtagPostsData;
  final UserModel currentUser;
  final List<PollOptionModel> pollOptionsList;
  final List<PollVoteModel> pollVotesList;

  final loc;

  @override
  _HashtagPostsState createState() => _HashtagPostsState();
}

class _HashtagPostsState extends State<HashtagPosts> {
  HttpService httpService;
  FeedRepository feedRepository;

  List<PostModel> postsList = [];
  String tagName;

  @override
  void initState() {
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    tagName = widget.hashtagPostsData[0].tag.tagName;

    getPosts();

    super.initState();
  }

  getPosts() {
    widget.hashtagPostsData.forEach((p) {
      postsList.insert(0, p.post);
    });
  }

  @override
  Widget build(BuildContext context) {
    return Directionality(
        textDirection: TextDirection.ltr,
        child: ScreenUtilInit(
            designSize: Size(375.0, 812.0),
            allowFontScaling: false,
            builder: () => Scaffold(
                backgroundColor: Color(0xffE8ECEF),
                appBar: PreferredSize(
                  preferredSize: Size.fromHeight(70.0),
                  child: AppBar(
                    backgroundColor: Color(0xFF083356),
                    leading: Padding(
                      padding: EdgeInsets.only(
                        top: ScreenUtil().setWidth(9),
                      ),
                      child: IconButton(
                        onPressed: () {
                          Navigator.pop(context);
                        },
                        icon: Icon(Icons.arrow_back, color: Colors.white),
                      ),
                    ),
                  ),
                ),
                body: _buildContent(postsList, tagName))));
  }

  _buildContent(listToShow, tagName) {
    return Stack(children: [
      RefreshIndicator(
          onRefresh: () => null,
          child: ListView.separated(
            cacheExtent: 1,
            itemCount: listToShow.length + 1,
            itemBuilder: (BuildContext context, int index) {
              if (index == 0) {
                return Container(
                    color: Color(0xffE8ECEF),
                    child: Column(children: [
                      _buildProfile(tagName),
                      _buildDetails(),
                    ]));
              }
              PostModel post = listToShow[index - 1];
              List<PollVoteModel> pollVotesListToQuestion = [];
              List<PollOptionModel> pollOptionsListToPost = [];
              if (post.pollQuestion != null) {
                pollVotesListToQuestion = post.pollQuestion != null
                    ? this
                        .widget
                        .pollVotesList
                        .where((p) =>
                            p.pollOption.pollQuestion.id ==
                            post.pollQuestion.id)
                        .toList()
                    : null;
                pollOptionsListToPost = widget.pollOptionsList
                    .where((p) => p.pollQuestion.id == post.pollQuestion.id)
                    .toList();
              }
              return FeedPost(
                key: Key("F" + post.id.toString()),
                postData: post,
                likeId: 1,
                dislikeId: 2,
                saveId: 3,
                currentUser: widget.currentUser,
                images: post.attachedUrl.split("*"),
                commentsLength: 0,
                loc: widget.loc,
                postsList: listToShow,
                generalPollOptionsList: this.widget.pollOptionsList,
                pollOptionsList: pollOptionsListToPost,
                pollVotesList: pollVotesListToQuestion,
              );
            },
            separatorBuilder: (BuildContext context, int index) =>
                const Divider(),
          ))
    ]);
  }

  _buildProfile(tagName) {
    return Container(
        color: Colors.white,
        child: Padding(
            padding: EdgeInsets.only(
              left: ScreenUtil().setHeight(17),
              top: ScreenUtil().setHeight(20),
              bottom: ScreenUtil().setHeight(20),
            ),
            child: Row(children: [
              Column(
                children: [
                  Container(
                    height: ScreenUtil().setHeight(44),
                    margin: EdgeInsets.only(
                      right: ScreenUtil().setWidth(10),
                    ),
                    child: ClipOval(
                      child: Image.network(
                        "https://res.cloudinary.com/feed-phonedo/image/upload/v1623660382/number-circle-512_ao6tk1.png",
                        width: ScreenUtil().setWidth(50),
                        height: ScreenUtil().setHeight(34),
                        fit: BoxFit.cover,
                      ),
                    ),
                  ),
                ],
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Container(
                    width:
                        ScreenUtil().screenWidth - ScreenUtil().setWidth(163),
                    child: Text(
                      tagName,
                      textAlign: TextAlign.left,
                      maxLines: 1,
                      style: TextStyle(
                        fontWeight: FontWeight.w500,
                        color: Colors.black,
                        fontSize: ScreenUtil().setSp(17),
                        fontFamily: 'Rubik',
                      ),
                    ),
                  ),
                ],
              ),
            ])));
  }

  _buildDetails() {
    return Container(
      color: Colors.white,
      padding: EdgeInsets.only(bottom: ScreenUtil().setHeight(5)),
      child: Row(
        children: [
          Expanded(
              child: Column(
            children: [
              Text(
                postsList.length.toString(),
                style: TextStyle(fontWeight: FontWeight.bold),
              ),
              Text(this.widget.loc.translate("Posts")),
            ],
          )),
          Expanded(
            child: Column(
              children: [
                Text(
                  "100K",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                Text(this.widget.loc.translate("Followers")),
              ],
            ),
          ),
          Expanded(
            child: Column(
              children: [
                Text(
                  "397",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                Text(this.widget.loc.translate("Following")),
              ],
            ),
          )
        ],
      ),
    );
  }
}
