import 'package:feed_plugin/environment_config.dart';
import 'package:feed_plugin/feed_plugin.dart';
import 'package:feed_plugin/models/poll_option_model.dart';
import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/models/story/storyModel.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/pages/share_story.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/story/story.dart';
import 'package:feed_plugin/widgets/story/story_button.dart';
import 'package:flutter_mobile_carousel/carousel.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter/material.dart';
import 'dart:async';
import 'package:intl/intl.dart';
import 'package:datetime_picker_formfield/datetime_picker_formfield.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/pages/my_feed.dart';
import 'package:feed_plugin/pages/partner_feed.dart';
import 'package:feed_plugin/pages/share_post_page.dart';
import 'package:feed_plugin/widgets/loadingButtonIndicator.dart';
import 'package:feed_plugin/widgets/post.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:inview_notifier_list/inview_notifier_list.dart';
import 'package:pusher_client/pusher_client.dart';
import 'dart:convert';
import 'package:empty_widget/empty_widget.dart';

final lastDate = new DateTime(
  DateTime.now().year - 10,
  DateTime.now().month,
);

String selectedValue = lastDate.toString();
String date;

class HomePage extends StatefulWidget {
  const HomePage(
      {Key key,
      this.token,
      this.firstName,
      this.lastName,
      this.about,
      this.profileImg,
      this.partnerName,
      this.partnerProfileImg,
      this.partnerMedia,
      this.loc})
      : super(key: key);

  final String token;
  final String firstName;
  final String lastName;
  final String about;
  final String profileImg;
  final String partnerName;
  final String partnerProfileImg;
  final partnerMedia;
  final loc;

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage>
    with SingleTickerProviderStateMixin {
  final int increment = 1;

  bool isLoadingVertical = false;

  List<PostModel> postsList = [];

  List<PostModel> postsListFilter = [];

  UserModel currentUser;

  UserModel currentPartner;

  bool newPostFlag = false;

  // PusherClient pusher;

  Channel channel;

  ScrollController _scrollController = new ScrollController();

  double defaultScreenWidth = 375.0;

  double defaultScreenHeight = 812.0;

  final int likeId = 1;

  final int dislikeId = 3;

  final int saveId = 2;

  bool flagFilter;

  int count;

  HttpService httpService;

  FeedRepository feedRepository;

  List<FeedPost> list;

  List<UserModel> userList = [];

  List<Widget> usersWidget = [];

  List<PollOptionModel> pollOptionsList = [];

  List<PostModel> pollPostsList = [];

  List<PostModel> favoritePostsList = [];

  TabController _controller;

  bool isMyFeedPage = false;

  List<PostModel> myPosts;

  List<PollVoteModel> pollVotesList = [];

  List<PollVoteModel> pollVotesListToQuestion = [];

  StoryModel currentUserStory;

  var media = {
    "website": "https://www.kikar.co.il/",
    "whatsapp": "972-504116642",
    "facebook": "https://www.facebook.com/",
    "instagram": "https://www.instagram.com/",
    "email": "cellcom@gmail.com",
    "phoneNumber": "972-508779672",
    "youtube": "https://www.youtube.com/",
    "twitter": "https://twitter.com/twitter",
    "linkedin": "https://www.linkedin.com/",
    "tiktok": "https://www.tiktok.com/he-IL/"
  };

  @override
  void initState() {
    _controller = new TabController(length: 2, vsync: this);
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    flagFilter = false;
    count = 0;
    initPusher();
    getCurrentUser();

    super.initState();
  }

  dispose() {
    _scrollController.dispose();
    super.dispose();
  }

  Future<void> initPusher() async {
    // pusher = PusherClient(
    //   EnvironmentConfig.PUSHER_ENV,
    //   PusherOptions(
    //     cluster: "ap2",
    //   ),
    //   autoConnect: false,
    // );
    channel = FeedPlugin.pusher.subscribe('post');
    channel.bind(
      'create_post',
      (onEvent) async {
        List<dynamic> newPost = json.decode(onEvent.data);
        List<PostModel> postsList =
            newPost.map((i) => PostModel.fromJson(i)).toList();
        List<PostModel> posts1 = postsListFilter.reversed.toList();
        if (postsList[0].pollQuestion != null) {
          await feedRepository.getAllOptions().then((value) async => {
                setState(() {
                  pollOptionsList = value;
                })
              });
        }

        if (mounted) {
          this.setState(() {
            posts1.add(postsList[0]);
            postsListFilter = posts1.reversed.toList();
            postsList = posts1.reversed.toList();
            newPostFlag = true;
            pollPostsList =
                postsListFilter.where((p) => p.pollQuestion != null).toList();
          });
        }
      },
    );

    channel.bind(
      'remove_post',
      (onEvent) {
        int postId = int.parse(onEvent.data);
        List<PostModel> posts = [];
        postsListFilter.forEach(
          (post) {
            if (post.id != postId) {
              posts.add(post);
            }
          },
        );
        if (mounted) {
          this.setState(
            () {
              postsListFilter = posts;
              postsList = posts;
            },
          );
        }
      },
    );
  }

  getStories() async {
    List<Widget> wl = [];
    List<PostModel> userPosts = [];
    List<UserModel> users;
    Widget storyButton;

    await feedRepository.getStoriesToday().then((stories) => {
          users = [],
          stories.forEach((s) {
            if (s.user.id == currentUser?.id) {
              setState(() {
                currentUserStory = s;
              });
            }
            users.add(s.user);
            var userClip = s.user.profileImg != null &&
                    s.user.profileImg != "" &&
                    s.user.profileImg != "null"
                ? GestureDetector(
                    onTap: () => {
                      userPosts = postsListFilter
                          .where((p) => p.user.id == s.user.id)
                          .toList(),
                      Navigator.push(
                        context,
                        MaterialPageRoute(
                          builder: (context) => StoryPage(
                            images: s.attachedUrl.split("*"),
                            user: s.user,
                            text: s.text.split("K*K"),
                            type: s.type.split("*"),
                          ),
                        ),
                      )
                    },
                    child: Container(
                      padding: const EdgeInsets.all(4.0),
                      margin: const EdgeInsets.all(4.0),
                      height: ScreenUtil().setHeight(5),
                      decoration: new BoxDecoration(
                        shape: BoxShape.circle,
                        border: new Border.all(
                          color: Colors.grey,
                          width: 0.6,
                        ),
                      ),
                      child: ClipOval(
                        child: Image.network(
                          s.user.profileImg,
                          fit: BoxFit.cover,
                        ),
                      ),
                    ),
                  )
                : GestureDetector(
                    onTap: () => {
                          userPosts = postsListFilter
                              .where((p) => p.user.id == s.user.id)
                              .toList(),
                          Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (context) => StoryPage(
                                      user: s.user,
                                      images: s.attachedUrl.split("*"),
                                      text: s.text.split("K*K"),
                                      type: s.type.split("*"),
                                    )),
                          )
                        },
                    child: Container(
                        padding: const EdgeInsets.all(4.0),
                        margin: const EdgeInsets.all(4.0),
                        height: ScreenUtil().setHeight(5),
                        decoration: new BoxDecoration(
                          shape: BoxShape.circle,
                          border: new Border.all(
                            color: Colors.grey,
                            width: 0.6,
                          ),
                        ),
                        child: DefaultProfileImg(
                            firstName: s.user.firstName,
                            lastName: s.user.lastName)));

            wl.add(userClip);
          }),
          storyButton = GestureDetector(
              onTap: () async {
                var res = await Navigator.push(
                    context,
                    MaterialPageRoute(
                        builder: (context) => ShareStoryPage(
                              currentUser: currentUser,
                              loc: widget.loc,
                              currentUserStory: currentUserStory,
                            )));
                getStories();
              },
              child: StoryButtonPage(
                  currentUser: currentUser,
                  loc: widget.loc,
                  currentUserStory: currentUserStory)),
          wl.insert(0, storyButton),
          setState(() => {
                userList = users,
                usersWidget = wl,
              }),
        });
  }

  Future<List<PostModel>> getPosts() async {
    List<PostModel> posts = [];
    posts = await loadPosts();
    return posts;
  }

  Future<UserModel> getCurrentUser() async {
    //אם יש פרטנר
    if (widget.partnerName != null &&
        widget.partnerName != "null" &&
        widget.partnerName.trim() != "") {
      await feedRepository
          .authenticatePartner(
              firstName: widget.partnerName,
              lastName: null,
              about: null,
              profileImg: widget.partnerProfileImg,
              token: null,
              socialMedia: widget.partnerMedia,
              partnerId: null)
          .then((partner) async => {
                await feedRepository
                    .authenticateUser(
                        firstName: widget.firstName,
                        lastName: widget.lastName,
                        about: widget.about,
                        profileImg: widget.profileImg,
                        token: widget.token,
                        socialMedia: null,
                        partnerId: partner.id)
                    .then((user) async => {
                          setState(
                            () {
                              currentUser = user;
                              currentPartner = partner;
                            },
                          ),
                          getPosts()
                        })
              });
    } else {
      //אם אין פרטנר אז הפרטנר הוא פונדו
      await feedRepository
          .authenticatePartner(
              firstName: "phonedo",
              lastName: null,
              about: null,
              profileImg:
                  "https://phonedo-media.fra1.digitaloceanspaces.com/2021/8/4/b20e473352ee688ed18faadc29b2e65a.png",
              token: null,
              socialMedia: jsonEncode(media),
              partnerId: null)
          .then((partner) async => {
                await feedRepository
                    .authenticateUser(
                        firstName: widget.firstName,
                        lastName: widget.lastName,
                        about: widget.about,
                        profileImg: widget.profileImg,
                        token: widget.token,
                        socialMedia: null,
                        partnerId: partner.id)
                    .then((user) async => {
                          setState(
                            () {
                              currentUser = user;
                              currentPartner = partner;
                            },
                          ),
                          getPosts()
                        })
              });
    }

    return currentUser;
  }

  void startTimer(int num) {
    count = num;
    Timer.periodic(
      Duration(seconds: 1),
      (_timer) {
        if (count > 0) {
          count--;
        } else {
          _timer.cancel();
          setState(
            () {
              newPostFlag = false;
            },
          );
        }
      },
    );
  }

  bool filter({@required DateTime createdAt, @required String selectedDate}) {
    DateTime fromDate = createdAt;
    DateTime toDate = new DateFormat("yyyy-MM-dd hh:mm:ss").parse(selectedDate);
    if (fromDate.isAfter(toDate) || toDate == fromDate) {
      return true;
    }
    return false;
  }

  bool filterByDay(
      {@required DateTime createdAt, @required String selectedDate}) {
    DateTime theDate =
        new DateFormat("yyyy-MM-dd hh:mm:ss").parse(selectedDate);
    setState(
      () {
        flagFilter = true;
      },
    );
    if (theDate.day == createdAt.day &&
        theDate.month == createdAt.month &&
        theDate.year == createdAt.year) {
      return true;
    }
    return false;
  }

  void getPostsByFilter() {
    List<PostModel> postsListTemp = [];

    for (var i = 0; i < postsList.length; i++) {
      if (filterByDay(
          createdAt: postsList[i].createdAt, selectedDate: selectedValue)) {
        postsListTemp.add(postsList[i]);
      }
    }
    setState(
      () {
        postsListFilter = postsListTemp;
      },
    );
  }

  List<PostModel> posts = [];

  Future<List<PostModel>> loadPosts() async {
    postsListFilter = [];
    await feedRepository.getAllOptions().then((value) async => {
          setState(() {
            pollOptionsList = value;
          })
        });
    await feedRepository.getAllVotes().then((value) async => {
          setState(() {
            pollVotesList = value;
          })
        });
    await getStories();
    await feedRepository.loadPosts().then((value) async => {
          setState(() {
            if (value.length < 1) {
              flagFilter = true;
            }
            posts = value;
            postsListFilter = posts.reversed.toList();
            postsList = posts.reversed.toList();
            pollPostsList =
                postsListFilter.where((p) => p.pollQuestion != null).toList();
            myPosts = postsListFilter
                .where((p) => p.user.id == currentUser.id)
                .toList();
          }),
        });
    return postsListFilter;
  }

  Future refreshData() async {
    await getPosts();
    return;
  }

  @override
  void didChangeDependencies() {
    getStories();
    super.didChangeDependencies();
  }

  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return ScreenUtilInit(
        designSize: Size(width, height),
        allowFontScaling: false,
        builder: () => Scaffold(
              appBar: PreferredSize(
                preferredSize: Size.fromHeight(70.0),
                child: AppBar(
                  automaticallyImplyLeading: false,
                  backgroundColor: Color(0xFF083356),
                  title: Row(
                    children: [
                      _buildMyFeedButton(),
                      _buildTitle(),
                      _buildPartnerButton(),
                    ],
                  ),
                ),
              ),
              body: _buildBody(),
            ));
  }

  _buildPartnerButton() {
    return Container(
        margin: EdgeInsets.only(top: ScreenUtil().setWidth(12)),
        child: currentUser != null && currentPartner != null
            ? GestureDetector(
                onTap: () {
                  // Media media = Media.fromJson(jsonDecode(widget.partnerMedia));
                  List<PostModel> partnerPosts = postsListFilter
                      .where((p) => p.user.id == currentPartner.id)
                      .toList();
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (context) => PartnerFeedPage(
                        loc: this.widget.loc,
                        currentUser: this.currentUser,
                        saveId: saveId,
                        likeId: likeId,
                        dislikeId: dislikeId,
                        // profileImg: widget.partnerProfileImg,
                        // firstName: widget.partnerName,
                        // media: currentPartner.media,
                        pollOptionsList: pollOptionsList,
                        pollVotesList: pollVotesList,
                        currentPartner: currentPartner,
                        partnerPosts: partnerPosts,
                      ),
                    ),
                  );
                },
                child: Container(
                  alignment: Alignment.bottomRight,
                  child: currentPartner.profileImg == null ||
                          currentPartner.profileImg == "" ||
                          currentPartner.profileImg == "null"
                      ? DefaultProfileImg(
                          firstName: this.widget.partnerName,
                        )
                      : ClipOval(
                          child: Image.network(
                            currentPartner.profileImg,
                            width: ScreenUtil().setWidth(40),
                            height: ScreenUtil().setWidth(40),
                            fit: BoxFit.cover,
                          ),
                        ),
                ),
              )
            : Container());
  }

  _buildMyFeedButton() {
    return this.currentUser != null
        ? GestureDetector(
            onTap: () async {
              List<PostModel> myPosts = postsListFilter
                  .where((p) => p.user.id == currentUser.id)
                  .toList();
              await Navigator.push(
                context,
                MaterialPageRoute(
                  builder: (context) => MyFeedPage(
                    currentUser: this.currentUser,
                    saveId: saveId,
                    likeId: likeId,
                    dislikeId: dislikeId,
                    postsList1: myPosts,
                    pollOptionsList: pollOptionsList,
                    loc: this.widget.loc,
                    withPartner: widget.partnerName != null &&
                            widget.partnerName != "null" &&
                            widget.partnerName != ""
                        ? true
                        : false,
                  ),
                ),
              ).then((value) async => {
                    await loadPosts(),
                  });
            },
            child: Padding(
              padding: EdgeInsets.only(top: ScreenUtil().setWidth(12)),
              child: Container(
                alignment: Alignment.centerLeft,
                child: this.currentUser.profileImg != null &&
                        this.currentUser.profileImg != "" &&
                        this.currentUser.profileImg != "null"
                    ? ClipOval(
                        child: Image.network(
                          this.currentUser.profileImg,
                          width: ScreenUtil().setWidth(38),
                          height: ScreenUtil().setWidth(39),
                          fit: BoxFit.cover,
                        ),
                      )
                    : DefaultProfileImg(
                        firstName: this.widget.firstName,
                        lastName: this.widget.lastName),
              ),
            ),
          )
        : Container();
  }

  _buildTitle() {
    return Expanded(
      child: Container(
        child: Text(
          this.widget.loc.translate('Feed'),
          textAlign: TextAlign.center,
          style: TextStyle(color: Colors.white),
        ),
      ),
    );
  }

  _buildBody() {
    return postsListFilter.length < 1 && flagFilter
        ? Stack(
            children: [
              _buildEmptyWidget(),
              _buildSharePostButton(),
            ],
          )
        : postsListFilter.length < 1 && !flagFilter
            ? Center(child: LoadingIndicatorDark())
            : Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: [
                  if (newPostFlag == true) _newPostButton(),
                  _buildDateField(),
                  Expanded(
                    child: this.currentUser != null
                        ? Stack(
                            children: [
                              _buildList(),
                              _buildSharePostButton(),
                            ],
                          )
                        : Container(),
                  ),
                ],
              );
  }

  _buildEmptyWidget() {
    return GestureDetector(
      onTap: () {
        setState(
          () {
            postsListFilter = postsList;
            if (postsList.length > 0) {
              flagFilter = false;
            }
          },
        );
      },
      child: Center(
        child: EmptyWidget(
          title: this.widget.loc.translate('No Data Found'),
          subTitle: this.widget.loc.translate('Click here to see all posts'),
          packageImage: PackageImage.Image_3,
          titleTextStyle: Theme.of(context)
              .typography
              .dense
              .headline4
              .copyWith(color: Color(0xff9da9c7)),
          subtitleTextStyle:
              Theme.of(context).typography.dense.bodyText1.copyWith(
                    color: Color(0xffabb8d6),
                  ),
        ),
      ),
    );
  }

  _newPostButton() {
    startTimer(7);
    return Column(
      children: [
        Container(
          decoration: BoxDecoration(
            border: Border(
              bottom: BorderSide(
                width: 15,
                color: Color(0xffE8ECEF),
              ),
            ),
          ),
        ),
        Container(
          color: Colors.white,
          height: ScreenUtil().setHeight(64),
          width: ScreenUtil().screenWidth,
          alignment: Alignment.center,
          child: SizedBox(
            height: ScreenUtil().setHeight(50),
            width: ScreenUtil().setWidth(280),
            child: Container(
              decoration: ShapeDecoration(
                color: Color(0xFF3DD598),
                shape: RoundedRectangleBorder(
                  side: BorderSide(
                      color: Colors.transparent,
                      width: 1,
                      style: BorderStyle.solid),
                  borderRadius: BorderRadius.circular(60),
                ),
              ),
              child: TextButton(
                onPressed: () {
                  startTimer(0);
                  _scrollController.animateTo(
                      _scrollController.position.minScrollExtent,
                      duration: Duration(seconds: 1),
                      curve: Curves.fastOutSlowIn);
                },
                child: Row(
                  children: [
                    Expanded(
                      flex: 2,
                      child: Container(
                        alignment: Alignment.center,
                        child: Text(
                          this.widget.loc.translate('New Post'),
                          style: TextStyle(
                            fontSize: ScreenUtil().setSp(16),
                            color: Colors.white,
                            fontFamily: 'Rubik',
                          ),
                        ),
                      ),
                    ),
                    Expanded(
                      child: Icon(
                        Icons.arrow_forward,
                        size: ScreenUtil().setWidth(25),
                        color: Colors.white,
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        ),
      ],
    );
  }

  _buildDateField() {
    final format = DateFormat("dd/MM/yyyy");
    final TextEditingController controller = TextEditingController();
    final now = DateTime.now();

    final nextYear = new DateTime(
      now.year,
      now.month,
      now.day,
    );
    return Column(
      children: [
        Container(
          decoration: BoxDecoration(
            border: Border(
              bottom: BorderSide(
                width: 15,
                color: Color(0xffE8ECEF),
              ),
            ),
          ),
        ),
        Container(
          color: Colors.white,
          height: ScreenUtil().setHeight(50),
          width: ScreenUtil().screenWidth,
          alignment: Alignment.center,
          child: SizedBox(
            height: ScreenUtil().setHeight(40),
            width: ScreenUtil().screenWidth - ScreenUtil().setWidth(30),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Flexible(
                  flex: 8,
                  child: Container(
                    decoration: ShapeDecoration(
                        color: Color(0xffE8ECEF),
                        shape: RoundedRectangleBorder(
                          side: BorderSide(
                              color: Colors.transparent,
                              width: 1,
                              style: BorderStyle.solid),
                          borderRadius: BorderRadius.circular(7),
                        )),
                    child: DateTimeField(
                      textAlign: TextAlign.center,
                      readOnly: true,
                      onChanged: (value) {
                        setState(
                          () {
                            selectedValue = value.toString();
                            date = DateFormat("dd/MM/yyyy").format(value);
                          },
                        );
                        getPostsByFilter();
                      },
                      controller: controller,
                      format: format,
                      onShowPicker: (context, currentValue) {
                        return showDatePicker(
                            context: context,
                            firstDate: lastDate,
                            initialDate: currentValue ?? DateTime.now(),
                            lastDate: nextYear);
                      },
                      decoration: new InputDecoration(
                          prefixIcon: Icon(
                            Icons.filter_list_rounded,
                            color: Color(0xFF083356),
                          ),
                          labelText: flagFilter
                              ? date
                              : this.widget.loc.translate("filter..."),
                          labelStyle: TextStyle(
                            color: Color(0xFF083356),
                          ),
                          border:
                              OutlineInputBorder(borderSide: BorderSide.none)),
                    ),
                  ),
                ),
                Flexible(
                    flex: 1,
                    child: Container(
                      child: IconButton(
                        padding: const EdgeInsets.all(0.0),
                        onPressed: () => {
                          setState(() =>
                              {flagFilter = false, postsListFilter = postsList})
                        },
                        icon: Icon(Icons.autorenew_rounded),
                        color: Color(0xFF083356),
                      ),
                    )),
              ],
            ),
          ),
        ),
        Container(
          decoration: BoxDecoration(
            border: Border(
              bottom: BorderSide(
                width: 15,
                color: Color(0xffE8ECEF),
              ),
            ),
          ),
        ),
      ],
    );
  }

  _buildList() {
    return RefreshIndicator(
        triggerMode: RefreshIndicatorTriggerMode.anywhere,
        onRefresh: () => getPosts(),
        child: InViewNotifierList(
          controller: _scrollController,
          scrollDirection: Axis.vertical,
          initialInViewIds: ['0'],
          isInViewPortCondition:
              (double deltaTop, double deltaBottom, double viewPortDimension) {
            return deltaTop < (0.1 * viewPortDimension) &&
                deltaBottom > (0.8 * viewPortDimension);
          },
          itemCount: this.postsListFilter.length + 1,
          builder: (BuildContext context, int index) {
            return Container(
                color: Color(0xffE8ECEF),
                child: LayoutBuilder(
                  builder: (BuildContext context, BoxConstraints constraints) {
                    return InViewNotifierWidget(
                      id: '$index',
                      builder:
                          (BuildContext context, bool isInView, Widget child) {
                        if (index == 0) {
                          return _buildStoryContainer();
                        }
                        return _buildFeedPost(index, isInView);
                      },
                    );
                  },
                ));
          },
        ));
  }

  _buildStoryContainer() {
    return Container(
      margin: EdgeInsets.only(bottom: ScreenUtil().setHeight(8)),
      height: ScreenUtil().setHeight(105),
      color: Colors.white,
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Container(
            margin: EdgeInsets.only(
                bottom: ScreenUtil().setHeight(5),
                top: ScreenUtil().setHeight(10),
                right: ScreenUtil().setHeight(10),
                left: ScreenUtil().setHeight(10)),
            child: Text(
              widget.loc.translate("Story"),
              style: TextStyle(
                  fontSize: ScreenUtil().setSp(14),
                  fontWeight: FontWeight.w600),
            ),
          ),
          Carousel(
            rowCount: 6,
            children: usersWidget,
          ),
        ],
      ),
    );
  }

  _buildFeedPost(int index, bool isInView) {
    List<PollOptionModel> pollOptionsListToPost;
    PostModel post = this.postsListFilter[index - 1];
    List<String> images = postsListFilter[index - 1].attachedUrl != null &&
            postsListFilter[index - 1].attachedUrl != "null"
        ? this.postsListFilter[index - 1].attachedUrl.split("*")
        : [];
    if (post.pollQuestion != null) {
      pollOptionsListToPost = [];
      pollOptionsListToPost = pollOptionsList
          .where((p) => p.pollQuestion.id == post.pollQuestion.id)
          .toList();

      pollVotesListToQuestion = [];
      pollVotesListToQuestion = pollVotesList
          .where((p) => p.pollOption.pollQuestion.id == post.pollQuestion.id)
          .toList();
    }
    return FeedPost(
      key: Key("F" + post.id.toString()),
      postData: post,
      currentUser: this.currentUser,
      images: images,
      likeId: likeId,
      dislikeId: dislikeId,
      saveId: saveId,
      commentsLength: 0,
      postsList: this.postsList,
      pollOptionsList: pollOptionsListToPost,
      generalPollOptionsList: pollOptionsList,
      pollVotesList: pollVotesListToQuestion,
      loc: this.widget.loc,
      play: isInView,
    );
  }

  _buildSharePostButton() {
    return Align(
      alignment: Alignment(0.8, 0.65),
      child: Container(
        decoration: BoxDecoration(
          shape: BoxShape.circle,
          boxShadow: [
            BoxShadow(
              color: Colors.grey,
              blurRadius: 5.0,
              spreadRadius: 1.0,
            )
          ],
        ),
        child: ClipOval(
          child: Material(
            color: Color(0xFF3DD598),
            child: InkWell(
              child: SizedBox(
                width: 70,
                height: 70,
                child: Icon(Icons.add, size: 50.0, color: Colors.white),
              ),
              onTap: () {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                      builder: (context) => SharePostPage(
                          currentUser: this.currentUser, loc: this.widget.loc)),
                );
              },
            ),
          ),
        ),
      ),
    );
  }
}
