import 'dart:convert';
import 'package:feed_plugin/environment_config.dart';
import 'package:feed_plugin/feed_plugin.dart';
import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/pages/user_image_page.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/activities.dart';
import 'package:feed_plugin/widgets/calander/calendar.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/models/poll_option_model.dart';
import 'package:feed_plugin/widgets/post.dart';
import 'package:pusher_client/pusher_client.dart';

import 'home_page.dart';

class MyFeedPage extends StatefulWidget {
  const MyFeedPage({
    Key key,
    @required this.currentUser,
    @required this.saveId,
    @required this.likeId,
    @required this.dislikeId,
    @required this.postsList1,
    @required this.loc,
    @required this.pollOptionsList,
    @required this.withPartner,
  }) : super(key: key);
  final UserModel currentUser;
  final int saveId;
  final int likeId;
  final int dislikeId;
  final List<PostModel> postsList1;
  final List<PollOptionModel> pollOptionsList;
  final loc;
  final bool withPartner;
  @override
  _MyFeedPageState createState() => _MyFeedPageState();
}

class _MyFeedPageState extends State<MyFeedPage>
    with SingleTickerProviderStateMixin {
  HttpService httpService;
  FeedRepository feedRepository;

  List<PollVoteModel> pollVotesList = [];
  List<PostModel> postsList = [];
  List<PostModel> favoritePostsList = [];
  TabController _controller;
  bool fixedScroll;
  // PusherClient pusher;

  Channel channel;

  _loadVotes() async {
    return await feedRepository.getAllVotes().then((value) async => {
          setState(() {
            pollVotesList = value;
          }),
        });
  }

  getMyFavoriteFeedPost() async {
    List<PostModel> posts = [];
    await feedRepository
        .fetchFavoritePosts(this.widget.currentUser.id, this.widget.saveId)
        .then((value) => {
              value.forEach((e) {
                posts.add(e.post);
              }),
              setState(
                () {
                  favoritePostsList = posts.reversed.toList();
                },
              )
            });
  }

  Future<void> initPusher() async {
    // pusher = PusherClient(
    //   EnvironmentConfig.PUSHER_ENV,
    //   PusherOptions(
    //     cluster: "ap2",
    //   ),
    //   autoConnect: false,
    // );
    channel = FeedPlugin.pusher.subscribe('post');

    channel.bind(
      'remove_post',
      (onEvent) {
        int postId = int.parse(onEvent.data);
        List<PostModel> posts = [];
        bool flag = false;
        postsList.forEach(
          (post) {
            if (post.id != postId) {
              posts.add(post);
            } else {
              flag = true;
            }
          },
        );
        List<PostModel> posts2 = [];
        if (flag == false) {
          favoritePostsList.forEach(
            (post) {
              if (post.id != postId) {
                posts2.add(post);
              }
            },
          );
        }
        if (mounted) {
          this.setState(
            () {
              postsList = posts;
              favoritePostsList = posts2;
            },
          );
        }
      },
    );
  }

  @override
  void initState() {
    _controller = new TabController(length: 2, vsync: this);
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    postsList = widget.postsList1;
    initPusher();
    _loadVotes();
    getMyFavoriteFeedPost();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
      textDirection: TextDirection.ltr,
      child: ScreenUtilInit(
        designSize: Size(width, height),
        allowFontScaling: false,
        builder: () => Scaffold(
          backgroundColor: Color(0xffE8ECEF),
          appBar: PreferredSize(
              preferredSize: Size.fromHeight(70.0),
              child: AppBar(
                  backgroundColor: Color(0xFF083356),
                  leading: _buildBackButton(),
                  title: _buildTitle(),
                  actions: <Widget>[_buildCalendarButton()])),
          body: _buildContent(this.widget.currentUser),
        ),
      ),
    );
  }

  _buildBackButton() {
    return Padding(
      padding: EdgeInsets.only(
        top: ScreenUtil().setWidth(9),
      ),
      child: IconButton(
        onPressed: () {
          Navigator.pop(
            context,
            HomePage(
                about: this.widget.currentUser.about,
                firstName: this.widget.currentUser.firstName,
                lastName: this.widget.currentUser.lastName,
                profileImg: this.widget.currentUser.profileImg,
                loc: this.widget.loc),
          );
        },
        icon: Icon(Icons.arrow_back, color: Colors.white),
      ),
    );
  }

  _buildTitle() {
    return Padding(
      padding: EdgeInsets.only(
          right: ScreenUtil().setWidth(50), top: ScreenUtil().setWidth(9)),
      child: Center(
          child: Text(
        this.widget.loc.translate("My Feed"),
        style: TextStyle(color: Colors.white),
      )),
    );
  }

  _buildCalendarButton() {
    return Container(
        child: GestureDetector(
      onTap: () {
        showDialog(
            context: context,
            builder: (BuildContext context) {
              return Calendar(
                loc: widget.loc,
              );
            });
      },
      child: Padding(
        padding: EdgeInsets.only(
            right: ScreenUtil().setWidth(10), top: ScreenUtil().setWidth(9)),
        child: Container(
            alignment: Alignment.centerRight,
            child: Icon(Icons.date_range_outlined)),
      ),
    ));
  }

  _buildContent(currentUser) {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: Stack(
        children: [
          _buildTabBarView(),
        ],
      ),
    );
  }

  _buildProfile(currentUser) {
    return Container(
        color: Colors.white,
        child: Padding(
            padding: EdgeInsets.only(
              left: ScreenUtil().setHeight(17),
              top: ScreenUtil().setHeight(20),
              bottom: ScreenUtil().setHeight(15),
            ),
            child: Row(children: [
              Column(
                children: [
                  Container(
                    margin: EdgeInsets.only(
                      right: ScreenUtil().setWidth(10),
                    ),
                    child: currentUser.profileImg == null ||
                            currentUser.profileImg == "" ||
                            currentUser.profileImg == "null"
                        ? ClipOval(
                            child: Material(
                              color: Color(0xffE8ECEF),
                              child: SizedBox(
                                width: ScreenUtil().setWidth(49),
                                height: ScreenUtil().setHeight(50),
                                child: Center(
                                  child: Text(
                                    currentUser.firstName != null &&
                                            currentUser.firstName != "" &&
                                            currentUser.lastName != null &&
                                            currentUser.lastName != ""
                                        ? currentUser.firstName
                                                .substring(0, 1) +
                                            currentUser.lastName.substring(0, 1)
                                        : (currentUser.firstName == null ||
                                                    currentUser.firstName ==
                                                        "") &&
                                                currentUser.lastName != null &&
                                                currentUser.lastName != ""
                                            ? currentUser.lastName
                                                .substring(0, 1)
                                            : (currentUser.lastName == null ||
                                                        currentUser.lastName ==
                                                            "") &&
                                                    currentUser.firstName !=
                                                        null &&
                                                    currentUser.firstName != ""
                                                ? currentUser.firstName
                                                    .substring(0, 1)
                                                : "",
                                    style: TextStyle(
                                      color: Color(0xFF083356),
                                      fontSize: ScreenUtil().setSp(15),
                                    ),
                                  ),
                                ),
                              ),
                            ),
                          )
                        : GestureDetector(
                            onTap: () {
                              Navigator.push(
                                context,
                                MaterialPageRoute(
                                  builder: (context) => UserImagePage(
                                    userData: this.widget.currentUser,
                                  ),
                                ),
                              );
                            },
                            child: ClipOval(
                              child: Image.network(
                                currentUser.profileImg,
                                width: ScreenUtil().setWidth(49),
                                height: ScreenUtil().setHeight(50),
                                fit: BoxFit.cover,
                              ),
                            ),
                          ),
                  ),
                ],
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Container(
                    width:
                        ScreenUtil().screenWidth - ScreenUtil().setWidth(163),
                    child: Text(
                      currentUser.lastName != null &&
                              currentUser.lastName != "null"
                          ? currentUser.firstName + " " + currentUser.lastName
                          : currentUser.firstName,
                      textAlign: TextAlign.left,
                      maxLines: 1,
                      style: TextStyle(
                        fontWeight: FontWeight.w500,
                        color: Colors.black,
                        fontSize: ScreenUtil().setSp(17),
                        fontFamily: 'Rubik',
                      ),
                    ),
                  ),
                  Container(
                    child: Text(
                      currentUser.about != null && currentUser.about != "null"
                          ? currentUser.about
                          : "",
                      textAlign: TextAlign.left,
                      maxLines: 1,
                      style: TextStyle(
                        fontWeight: FontWeight.normal,
                        color: Colors.black.withOpacity(0.4),
                        fontSize: ScreenUtil().setSp(15),
                        fontFamily: "Rubik",
                      ),
                    ),
                  ),
                ],
              ),
            ])));
  }

  _buildDetails() {
    return Container(
      color: Colors.white,
      padding: EdgeInsets.only(bottom: ScreenUtil().setHeight(5)),
      child: Row(
        children: [
          Expanded(
              // ignore: deprecated_member_use
              child: FlatButton(
                  onPressed: () {
                    print("aa");
                  },
                  child: Column(
                    children: [
                      Text(
                        postsList.length.toString(),
                        style: TextStyle(fontWeight: FontWeight.bold),
                      ),
                      Text(this.widget.loc.translate("Posts")),
                    ],
                  ))),
          Expanded(
            child: Column(
              children: [
                Text(
                  "100K",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                Text(this.widget.loc.translate("Followers")),
              ],
            ),
          ),
          Expanded(
            child: Column(
              children: [
                Text(
                  "397",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                Text(this.widget.loc.translate("Following")),
              ],
            ),
          )
        ],
      ),
    );
  }

  _activityButton() {
    return Container(
      margin: EdgeInsets.only(top: ScreenUtil().setHeight(2)),
      color: Colors.white,
      height: ScreenUtil().setHeight(80),
      alignment: Alignment.center,
      child: SizedBox(
        height: ScreenUtil().setHeight(40),
        width: ScreenUtil().setHeight(345),
        child: Container(
          decoration: ShapeDecoration(
              color: Colors.white,
              shape: RoundedRectangleBorder(
                side: BorderSide(
                    color: Colors.black, width: 1, style: BorderStyle.solid),
                borderRadius: BorderRadius.circular(5),
              )),
          child: FlatButton(
            onPressed: () {
              Navigator.push(
                context,
                MaterialPageRoute(
                    builder: (context) =>
                        BusinessProfilePage(loc: this.widget.loc)),
              );
            },
            child: Text(this.widget.loc.translate('View all activities'),
                style: TextStyle(color: Colors.black)),
          ),
        ),
      ),
    );
  }

  _buildTabBar() {
    return Column(
      children: <Widget>[
        Container(
          decoration: BoxDecoration(
            border: Border(
              bottom: BorderSide(
                width: ScreenUtil().setHeight(10),
                color: Color(0xffE8ECEF),
              ),
            ),
          ),
        ),
        Container(
          color: Colors.white,
          child: new TabBar(
            labelColor: Color(0xFFE083356),
            unselectedLabelColor: Color(0xFF083356),
            labelStyle: TextStyle(
                fontWeight: FontWeight.bold,
                fontSize: ScreenUtil().setWidth(13)),
            unselectedLabelStyle: TextStyle(
                fontWeight: FontWeight.normal,
                fontSize: ScreenUtil().setWidth(13)),
            indicatorColor: Color(0xFFE083356),
            indicatorWeight: 5.0,
            controller: _controller,
            tabs: [
              Tab(
                text: this.widget.loc.translate("Posts"),
              ),
              Tab(text: this.widget.loc.translate("Favorite")),
            ],
          ),
        ),
        Container(
          height: ScreenUtil().setHeight(5),
          color: Color(0xffE8ECEF),
        ),
      ],
    );
  }

  _buildTabBarView() {
    return TabBarView(
      controller: _controller,
      children: <Widget>[
        _buildList(postsList, "Posts"),
        _buildList(favoritePostsList, "Favorite"),
      ],
    );
  }

  _buildList(listToShow, type) {
    return RefreshIndicator(
        onRefresh: () {
          return getMyFavoriteFeedPost();
        },
        child: ListView(
          children: [
            _buildProfile(this.widget.currentUser),
            _buildDetails(),
            if (widget.withPartner) _activityButton(),
            _buildTabBar(),
            ListView.builder(
              shrinkWrap: true,
              physics: NeverScrollableScrollPhysics(),
              itemCount: listToShow.length,
              itemBuilder: (BuildContext context, int index) {
                PostModel post = listToShow[index];
                List<PollVoteModel> pollVotesListToQuestion = [];
                List<PollOptionModel> pollOptionsListToPost = [];
                if (post.pollQuestion != null) {
                  pollOptionsListToPost = [];
                  pollOptionsListToPost = widget.pollOptionsList
                      .where((p) => p.pollQuestion.id == post.pollQuestion.id)
                      .toList();
                  pollVotesListToQuestion = [];
                  pollVotesListToQuestion = this
                      .pollVotesList
                      .where((p) =>
                          p.pollOption.pollQuestion.id == post.pollQuestion.id)
                      .toList();
                }
                return FeedPost(
                    key: Key("F" + post.id.toString()),
                    postData: post,
                    likeId: this.widget.likeId,
                    dislikeId: this.widget.dislikeId,
                    saveId: this.widget.saveId,
                    currentUser: this.widget.currentUser,
                    images: post.attachedUrl.split("*"),
                    commentsLength: 0,
                    postsList: postsList,
                    pollOptionsList: pollOptionsListToPost,
                    generalPollOptionsList: this.widget.pollOptionsList,
                    pollVotesList: pollVotesListToQuestion,
                    loc: this.widget.loc);
              },
            ),
          ],
        ));
  }
}
