import 'package:feed_plugin/models/media.dart';
import 'package:feed_plugin/models/poll_option_model.dart';
import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/media.dart';
import 'package:feed_plugin/widgets/post.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:url_launcher/url_launcher.dart';

class PartnerFeedPage extends StatefulWidget {
  const PartnerFeedPage({
    Key key,
    @required this.currentUser,
    @required this.saveId,
    @required this.likeId,
    @required this.dislikeId,
    @required this.loc,
    // @required this.firstName,
    // @required this.media,
    // @required this.profileImg,
    @required this.pollOptionsList,
    @required this.pollVotesList,
    @required this.currentPartner,
    @required this.partnerPosts,
  }) : super(key: key);
  final UserModel currentUser;
  final UserModel currentPartner;
  final int saveId;
  final int likeId;
  final int dislikeId;
  final loc;
  // final String firstName;
  // final String profileImg;
  // final Media media;
  final List<PollOptionModel> pollOptionsList;
  final List<PollVoteModel> pollVotesList;
  final List<PostModel> partnerPosts;

  @override
  _PartnerFeedPageState createState() => _PartnerFeedPageState();
}

class _PartnerFeedPageState extends State<PartnerFeedPage>
    with SingleTickerProviderStateMixin {
  HttpService httpService;
  FeedRepository feedRepository;
  TabController _controller;

  @override
  void initState() {
    _controller = new TabController(length: 1, vsync: this);
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    print(widget.currentPartner.firstName);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
      textDirection: TextDirection.ltr,
      child: ScreenUtilInit(
        designSize: Size(width, height),
        allowFontScaling: false,
        builder: () => Scaffold(
          backgroundColor: Color(0xffE8ECEF),
          appBar: PreferredSize(
            preferredSize: Size.fromHeight(70.0),
            child: AppBar(
              backgroundColor: Color(0xFF083356),
              leading: _buildBackButton(),
              title: _buildTitle(),
            ),
          ),
          body: _buildContent(),
        ),
      ),
    );
  }

  _buildBackButton() {
    return Padding(
      padding: EdgeInsets.only(
        top: ScreenUtil().setWidth(9),
      ),
      child: IconButton(
        onPressed: () {
          Navigator.pop(context);
        },
        icon: Icon(Icons.arrow_back, color: Colors.white),
      ),
    );
  }

  _buildTitle() {
    return Padding(
      padding: EdgeInsets.only(
          right: ScreenUtil().setWidth(50), top: ScreenUtil().setWidth(9)),
      child: Center(
          child: Text(
        this.widget.currentPartner.firstName + this.widget.loc.translate(" Feed"),
        style: TextStyle(color: Colors.white),
      )),
    );
  }

  _buildContent() {
    return _buildView();
  }

  _buildView() {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: TabBarView(
        controller: _controller,
        children: <Widget>[_buildList(widget.partnerPosts, "Posts")],
      ),
    );
  }

  _buildList(listToShow, type) {
    return ListView(children: [
      _buildProfile(),
      _buildDetails(),
      _activityButton(),
      _buildContactInfo(),
      if (this.widget.currentPartner.media != null)
        MediaPage(
          whatsapp: this.widget.currentPartner.media.whatsapp,
          facebook: this.widget.currentPartner.media.facebook,
          instagram: this.widget.currentPartner.media.instagram,
          tiktok: this.widget.currentPartner.media.tiktok,
          twitter: this.widget.currentPartner.media.twitter,
          youtube: this.widget.currentPartner.media.youtube,
          linkedin: this.widget.currentPartner.media.linkedin,
          loc: this.widget.loc,
        ),
      _buildTabBar(),
      listToShow.length == 0
          ? Container(
              alignment: Alignment.center,
              child: Text(
                widget.loc.translate("No Posts Yet..."),
                style: TextStyle(
                  fontSize: ScreenUtil().setWidth(20),
                  color: Color(0xFF98A9BC),
                ),
              ),
            )
          : ListView.builder(
              shrinkWrap: true,
              physics: NeverScrollableScrollPhysics(),
              itemCount: listToShow.length,
              itemBuilder: (BuildContext context, int index) {
                PostModel post = listToShow[index];
                List<PollVoteModel> pollVotesListToQuestion = [];
                List<PollOptionModel> pollOptionsListToPost = [];
                if (post.pollQuestion != null) {
                  pollVotesListToQuestion = this
                      .widget
                      .pollVotesList
                      .where((p) =>
                          p.pollOption.pollQuestion.id == post.pollQuestion.id)
                      .toList();
                  pollOptionsListToPost = widget.pollOptionsList
                      .where((p) => p.pollQuestion.id == post.pollQuestion.id)
                      .toList();
                }
                return FeedPost(
                    postData: post,
                    likeId: this.widget.likeId,
                    dislikeId: this.widget.dislikeId,
                    saveId: this.widget.saveId,
                    currentUser: this.widget.currentUser,
                    images: post.attachedUrl.split("*"),
                    commentsLength: 0,
                    postsList: null,
                    pollOptionsList: pollOptionsListToPost,
                    generalPollOptionsList: this.widget.pollOptionsList,
                    pollVotesList: pollVotesListToQuestion,
                    loc: this.widget.loc);
              })
    ]);
  }

  _buildProfile() {
    return Container(
        color: Colors.white,
        child: Padding(
            padding: EdgeInsets.only(
              left: ScreenUtil().setHeight(17),
              top: ScreenUtil().setHeight(20),
              bottom: ScreenUtil().setHeight(15),
            ),
            child: Row(children: [
              Column(
                children: [
                  Container(
                    margin: EdgeInsets.only(
                      right: ScreenUtil().setWidth(10),
                    ),
                    child: widget.currentPartner.profileImg == null ||
                            widget.currentPartner.profileImg == "null" ||
                            widget.currentPartner.profileImg == ""
                        ? ClipOval(
                            child: Material(
                              color: Color(0xffE8ECEF),
                              child: SizedBox(
                                width: ScreenUtil().setWidth(49),
                                height: ScreenUtil().setHeight(50),
                                child: Center(
                                  child: Text(
                                    widget.currentPartner.firstName != null &&
                                            widget.currentPartner.firstName != ""
                                        ? widget.currentPartner.firstName.substring(0, 1)
                                        : "",
                                    style: TextStyle(
                                      color: Color(0xFF083356),
                                      fontSize: ScreenUtil().setSp(15),
                                    ),
                                  ),
                                ),
                              ),
                            ),
                          )
                        : ClipOval(
                            child: Image.network(
                              widget.currentPartner.profileImg,
                              width: ScreenUtil().setWidth(49),
                              height: ScreenUtil().setHeight(50),
                              fit: BoxFit.cover,
                            ),
                          ),
                  ),
                ],
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Container(
                    width:
                        ScreenUtil().screenWidth - ScreenUtil().setWidth(163),
                    child: Text(
                      this.widget.currentPartner.firstName,
                      textAlign: TextAlign.left,
                      maxLines: 1,
                      style: TextStyle(
                        fontWeight: FontWeight.w500,
                        color: Colors.black,
                        fontSize: ScreenUtil().setSp(17),
                        fontFamily: 'Rubik',
                      ),
                    ),
                  ),
                  Container(
                    width:
                        ScreenUtil().screenWidth - ScreenUtil().setWidth(165),
                    child: Text(
                      "",
                      textAlign: TextAlign.left,
                      maxLines: 1,
                      style: TextStyle(
                        fontWeight: FontWeight.normal,
                        color: Colors.black.withOpacity(0.4),
                        fontSize: ScreenUtil().setSp(15),
                        fontFamily: "Rubik",
                      ),
                    ),
                  ),
                ],
              ),
            ])));
  }

  _buildDetails() {
    return Container(
      color: Colors.white,
      padding: EdgeInsets.only(bottom: ScreenUtil().setHeight(5)),
      child: Row(
        children: [
          Expanded(
            // ignore: deprecated_member_use
            child: FlatButton(
              onPressed: () {},
              child: Column(
                children: [
                  Text(
                    widget.partnerPosts.length.toString(),
                    style: TextStyle(fontWeight: FontWeight.bold),
                  ),
                  Text(this.widget.loc.translate("Posts")),
                ],
              ),
            ),
          ),
          Expanded(
              child: Column(
            children: [
              Text(
                "100K",
                style: TextStyle(fontWeight: FontWeight.bold),
              ),
              Text(this.widget.loc.translate("Followers")),
            ],
          )),
          Expanded(
              child: Column(
            children: [
              Text(
                "397",
                style: TextStyle(fontWeight: FontWeight.bold),
              ),
              Text(this.widget.loc.translate("Following")),
            ],
          ))
        ],
      ),
    );
  }

  _activityButton() {
    return Container(
      margin: EdgeInsets.only(top: ScreenUtil().setHeight(2)),
      color: Colors.white,
      height: ScreenUtil().setHeight(80),
      alignment: Alignment.center,
      child: SizedBox(
        height: ScreenUtil().setHeight(40),
        width: ScreenUtil().setHeight(345),
        child: Container(
          decoration: ShapeDecoration(
              color: Colors.white,
              shape: RoundedRectangleBorder(
                side: BorderSide(
                    color: Colors.black, width: 1, style: BorderStyle.solid),
                borderRadius: BorderRadius.circular(5),
              )),
          child: FlatButton(
            onPressed: null,
            child: Text(
                this.widget.loc.translate('Follow ') + this.widget.currentPartner.firstName,
                style: TextStyle(color: Colors.black)),
          ),
        ),
      ),
    );
  }

  _buildContactInfo() {
    List val = [];
    List url = [];
    List type = [];
    if (this.widget.currentPartner.media.phoneNumber != null) {
      val.add(this.widget.loc.translate("Our Phone number:"));
      url.add(this.widget.currentPartner.media.phoneNumber);
      type.add("tel:");
    }
    if (this.widget.currentPartner.media.website != null) {
      val.add(this.widget.loc.translate("Our website:"));
      url.add(this.widget.currentPartner.media.website);
      if (widget.currentPartner.media.website.toString().substring(0, 8).toLowerCase() ==
              "https://" ||
          widget.currentPartner.media.website.toString().substring(0, 8).toLowerCase() ==
              "http://") {
        type.add("");
      } else {
        type.add("https://");
      }
    }
    if (this.widget.currentPartner.media.email != null) {
      val.add(this.widget.loc.translate("Our email:"));
      url.add(this.widget.currentPartner.media.email);
      type.add("mailto:");
    }

    List<Widget> rows = [];
    for (var i = 0; i < val.length; i++) {
      var R = Row(children: [
        Expanded(
          child: Text(this.widget.loc.translate(val[i]),
              style: TextStyle(
                fontSize: ScreenUtil().setSp(16),
                fontFamily: "Rubik",
              )),
        ),
        Expanded(
            child: TextButton(
                onPressed: () => launch(type[i] + url[i]),
                child: Container(
                  alignment: Alignment.centerRight,
                  child: Text(url[i],
                      style: TextStyle(
                        fontSize: ScreenUtil().setSp(16),
                        fontFamily: "Rubik",
                      )),
                )))
      ]);
      rows.add(R);
    }
    return Container(
      margin: EdgeInsets.only(top: ScreenUtil().setHeight(2)),
      color: Colors.white,
      height: val.length == 3
          ? ScreenUtil().setHeight(170)
          : val.length == 2
              ? ScreenUtil().setHeight(100)
              : val.length == 1
                  ? ScreenUtil().setHeight(50)
                  : ScreenUtil().setHeight(0),
      padding: EdgeInsets.only(
          left: ScreenUtil().setHeight(10), right: ScreenUtil().setHeight(10)),
      child: ListView(
        physics: const NeverScrollableScrollPhysics(),
        children: rows,
      ),
    );
  }

  _buildTabBar() {
    return Column(children: <Widget>[
      Container(
        decoration: BoxDecoration(
          border: Border(
            bottom: BorderSide(
              width: ScreenUtil().setHeight(10),
              color: Color(0xffE8ECEF),
            ),
          ),
        ),
      ),
      Container(
          color: Colors.white,
          child: new TabBar(
            labelColor: Color(0xFFE083356),
            unselectedLabelColor: Color(0xFF083356),
            labelStyle: TextStyle(fontWeight: FontWeight.bold),
            unselectedLabelStyle: TextStyle(fontWeight: FontWeight.normal),
            indicatorColor: Color(0xFFE083356),
            indicatorWeight: 5.0,
            controller: _controller,
            tabs: [
              Tab(text: this.widget.loc.translate("Posts")),
            ],
          )),
      Container(
        height: ScreenUtil().setHeight(5),
        color: Color(0xffE8ECEF),
      ),
    ]);
  }
}
