import 'dart:io';

import 'package:cloudinary_public/cloudinary_public.dart';
import 'package:feed_plugin/models/media_source.dart';
import 'package:feed_plugin/models/story/storyModel.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/pages/source_page.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/statusText.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:feed_plugin/widgets/video_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:multi_image_picker/multi_image_picker.dart';
import 'package:feed_plugin/utilities/colors.dart';

class ShareStoryPage extends StatefulWidget {
  const ShareStoryPage(
      {Key key,
      @required this.currentUser,
      @required this.loc,
      this.currentUserStory});

  final UserModel currentUser;
  final loc;
  final StoryModel currentUserStory;

  @override
  _ShareStoryPageState createState() => _ShareStoryPageState();
}

class _ShareStoryPageState extends State<ShareStoryPage> {
  HttpService httpService;
  FeedRepository feedRepository;

  String url = "https://api.cloudinary.com/v1_1/feed-phonedo";
  final cloudinary = CloudinaryPublic('feed-phonedo', 'edwhfpti', cache: false);

  final textController = TextEditingController();
  FocusNode focusNodeText;

  List<Asset> images = [];
  File video;
  MediaSource source;

  String statusText;
  String statusColor;

  bool flag;

  @override
  void initState() {
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    super.initState();
  }

  Future uplaodCloudinary(file, type) async {
    try {
      CloudinaryResponse response;
      List<CloudinaryResponse> responseList;
      var s = "";
      if (type == "Photo") {
        if (images.length == 1) {
          responseList = await cloudinary.multiUpload(
            images
                .map(
                  (image) => CloudinaryFile.fromFutureByteData(
                    image.getByteData(),
                    identifier: image.identifier,
                  ),
                )
                .toList(),
          );

          if (responseList[0].url[4] != "s") {
            s = responseList[0].url.substring(0, 4).toString() +
                "s" +
                responseList[0].url.substring(4).toString();
          } else {
            s = responseList[0].url;
          }
        }
      } else if (type == "Video") {
        response = await cloudinary.uploadFile(
          CloudinaryFile.fromFile(file.path,
              resourceType: CloudinaryResourceType.Video),
        );

        if (response.url[4] != "s") {
          s = response.url.substring(0, 4).toString() +
              "s" +
              response.url.substring(4).toString();
        } else {
          s = response.url;
        }
      }
      return s;
    } catch (e) {
      return e;
    }
  }

  createStory({file, String type, String text}) async {
    String attachedUrl;
    String fullAttachedUrl;
    String fullText;
    String fullType;

    //אם זה וידאו או תמונה
    if (type != "Text") {
      attachedUrl = await uplaodCloudinary(file, type);
      //אם יש כבר סטורי למשתמש הנוכחי
      if (widget.currentUserStory != null) {
        fullAttachedUrl =
            widget.currentUserStory.attachedUrl.toString() + "*" + attachedUrl;
        fullText = widget.currentUserStory.text.toString() + "K*K" + text;
        fullType = widget.currentUserStory.type.toString() + "*" + type;
        await feedRepository
            .updateStory(
                id: widget.currentUserStory.id,
                attachedUrl: fullAttachedUrl,
                text: fullText,
                type: fullType)
            .then((value) => {_onLoading(false).than(Navigator.pop(context))});
      }
      // אם אין לו עדיין סטורי
      else {
        await feedRepository
            .createStory(
                text: textController.text,
                user: widget.currentUser.id,
                attachedUrl: attachedUrl,
                type: type)
            .then((value) => {_onLoading(false).than(Navigator.pop(context))});
      }
    }
    //אם זה טקסט
    else {
      //אם יש לו כבר סטורי
      if (widget.currentUserStory != null) {
        fullAttachedUrl =
            widget.currentUserStory.attachedUrl.toString() + "*" + file;
        fullText = widget.currentUserStory.text.toString() + "K*K" + text;
        fullType = widget.currentUserStory.type.toString() + "*" + type;
        await feedRepository
            .updateStory(
                id: widget.currentUserStory.id,
                attachedUrl: fullAttachedUrl,
                text: fullText,
                type: fullType)
            .then((value) => {_onLoading(false).than(Navigator.pop(context))});
      }
      // אם אין לו עדיין סטורי
      else {
        await feedRepository
            .createStory(
                text: text,
                user: widget.currentUser.id,
                attachedUrl: file,
                type: type)
            .then((value) {
          _onLoading(false).than(Navigator.pop(context));
        });
      }
    }
  }

  Future getVideo(MediaSource sourceMedia) async {
    setState(() {
      source = sourceMedia;
      video = null;
    });

    final result = await Navigator.of(context).push(
      MaterialPageRoute(
        builder: (context) => SourcePage(loc: this.widget.loc),
        settings: RouteSettings(
          arguments: source,
        ),
      ),
    );

    if (result == null) {
      return;
    } else {
      setState(() {
        video = result;
      });
    }
  }

  Future<void> loadAssets() async {
    List<Asset> resultList = [];
    try {
      resultList = await MultiImagePicker.pickImages(
        maxImages: 1,
        enableCamera: true,
        selectedAssets: images,
        cupertinoOptions: CupertinoOptions(takePhotoIcon: "chat"),
        materialOptions: MaterialOptions(
          actionBarColor: "#083356",
          actionBarTitle: this.widget.loc.translate("Example App"),
          allViewTitle: this.widget.loc.translate("All Photos"),
          useDetailsView: false,
          selectCircleStrokeColor: "#000000",
        ),
      );
    } on Exception catch (e) {}

    if (!mounted) return;

    setState(() {
      images = resultList;
    });
  }

  Future<void> loadStatusText() async {
    List<dynamic> res;
    res = await Navigator.push(
        context, MaterialPageRoute(builder: (context) => StatusText()));
    setState(() => {
          statusText = res[0].toString(),
          statusColor = res[1].toString(),
        });
  }

  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
        textDirection: TextDirection.ltr,
        child: ScreenUtilInit(
          designSize: Size(width, height),
          allowFontScaling: false,
          builder: () => Scaffold(
            appBar: PreferredSize(
                preferredSize: Size.fromHeight(70.0),
                child: AppBar(
                    backgroundColor: Color(0xFF083356),
                    leading: Padding(
                      padding: EdgeInsets.only(
                        top: ScreenUtil().setWidth(9),
                      ),
                      child: IconButton(
                        onPressed: () {
                          Navigator.pop(context);
                        },
                        icon: Icon(Icons.close, color: Colors.white),
                      ),
                    ),
                    title: Container(
                      alignment: Alignment(-0.3, 0),
                      child: Padding(
                        padding: EdgeInsets.only(top: ScreenUtil().setWidth(9)),
                        child: Text(
                          this.widget.loc.translate("Story"),
                          textAlign: TextAlign.center,
                          style: TextStyle(
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ))),
            body: _buildBody(),
          ),
        ));
  }

  _buildBody() {
    return Stack(
      children: (images.length > 0 || video != null || statusText != null)
          ? [
              _buildContent(widget.currentUser),
              if ((video != null && flag == false) || video == null)
                Align(
                    alignment: Alignment(0.8, 0.8), child: _buildSendButton()),
            ]
          : [
              _buildContent(widget.currentUser),
              Align(
                  alignment: Alignment(0.8, 0.8),
                  child: _buildButton(Icons.videocam_outlined, "video")),
              Align(
                  alignment: Alignment(0.8, 0.55),
                  child: _buildButton(Icons.camera_alt_outlined, "image")),
              Align(
                  alignment: Alignment(0.8, 0.30),
                  child: _buildButton(Icons.edit, "edit")),
            ],
    );
  }

  _buildContent(currentUser) {
    return ListView(
      children: [
        Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
          _buildProfile(currentUser),
          Container(
              decoration: BoxDecoration(
                  color: Colors.grey[200],
                  border: Border.all(
                    color: Colors.grey[50],
                    width: 2.0,
                  )),
              height: ScreenUtil().setHeight(290),
              width: ScreenUtil().screenWidth,
              child: images.length > 0
                  ? _buildImage()
                  : video != null
                      ? _buildVideo()
                      : statusColor != null && statusText != null
                          ? _buildContainerText()
                          : Container()),
          images.length > 0 || video != null ? _buildText() : Container()
        ]),
      ],
    );
  }

  _buildProfile(currentUser) {
    return Container(
      decoration: BoxDecoration(
        color: Colors.white60,
        boxShadow: [
          BoxShadow(
            color: Colors.grey.withOpacity(0.3),
            spreadRadius: 5,
            blurRadius: 7,
          ),
        ],
      ),
      padding: EdgeInsets.only(
        top: 5,
        left: 5,
        right: 5,
      ),
      height: ScreenUtil().setHeight(100),
      margin: EdgeInsets.only(bottom: ScreenUtil().setHeight(20)),
      child: Container(
          child: Padding(
              padding: EdgeInsets.only(
                left: ScreenUtil().setHeight(17),
                top: ScreenUtil().setHeight(25),
                bottom: ScreenUtil().setHeight(25),
              ),
              child: Row(children: [
                Column(
                  children: [
                    Container(
                        margin: EdgeInsets.only(
                          right: ScreenUtil().setWidth(10),
                        ),
                        child: currentUser.profileImg == null ||
                                currentUser.profileImg == "" ||
                                currentUser.profileImg == "null"
                            ? DefaultProfileImg(
                                firstName: currentUser.firstName,
                                lastName: currentUser.lastName,
                              )
                            : ClipOval(
                                child: Image.network(
                                  currentUser.profileImg,
                                  width: ScreenUtil().setWidth(38),
                                  height: ScreenUtil().setWidth(39),
                                  fit: BoxFit.cover,
                                ),
                              )),
                  ],
                ),
                Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Container(
                      width:
                          ScreenUtil().screenWidth - ScreenUtil().setWidth(163),
                      child: Text(
                        currentUser.lastName != null &&
                                currentUser.lastName != "null"
                            ? currentUser.firstName + " " + currentUser.lastName
                            : currentUser.firstName,
                        textAlign: TextAlign.left,
                        maxLines: 1,
                        style: TextStyle(
                          fontWeight: FontWeight.w500,
                          color: Colors.black,
                          fontSize: ScreenUtil().setSp(15),
                          fontFamily: 'Rubik',
                        ),
                      ),
                    ),
                    Container(
                      width:
                          ScreenUtil().screenWidth - ScreenUtil().setWidth(165),
                      child: Text(
                        currentUser.about != null && currentUser.about != "null"
                            ? currentUser.about
                            : "",
                        textAlign: TextAlign.left,
                        maxLines: 1,
                        style: TextStyle(
                          fontWeight: FontWeight.normal,
                          color: Colors.black.withOpacity(0.4),
                          fontSize: ScreenUtil().setSp(13),
                          fontFamily: "Rubik",
                        ),
                      ),
                    ),
                  ],
                ),
              ]))),
    );
  }

  _buildImage() {
    if (images != null) {
      return Stack(children: [
        AssetThumb(
            asset: images[0],
            width: 500,
            height: ScreenUtil().setHeight(350).toInt()),
        _deleteIcon(images[0]),
      ]);
    } else {
      return Container();
    }
  }

  _buildVideo() {
    return Stack(
      children: [
        Container(
          height: ScreenUtil().setHeight(290),
          child: video == null
              ? Container(
                  height: 150,
                  color: Colors.green,
                )
              : (source == MediaSource.video
                  ? VideoWidget(
                      file: video,
                      flag: (val) {
                        setState(() {
                          flag = val;
                        });
                      },
                      seconds: 60)
                  : Container(
                      height: 150,
                      color: Colors.yellow,
                    )),
        ),
        _deleteIcon(video)
      ],
    );
  }

  _buildContainerText() {
    return Stack(children: [
      Container(
          decoration: BoxDecoration(
              color: storyColor[statusColor],
              border: Border.all(
                color: Colors.grey[50],
                width: 2.0,
              )),
          height: ScreenUtil().setHeight(290),
          width: ScreenUtil().screenWidth,
          child: Text(
            statusText,
            style: TextStyle(
                color: Colors.white, fontSize: ScreenUtil().setHeight(30)),
            textAlign: TextAlign.center,
          )),
      _deleteIcon(statusText)
    ]);
  }

  _buildText() {
    return Padding(
      padding: EdgeInsets.only(
        top: ScreenUtil().setHeight(30),
        left: ScreenUtil().setHeight(15),
        right: ScreenUtil().setHeight(15),
      ),
      child: Container(
        decoration: BoxDecoration(
            border: Border.all(
          color: Colors.grey,
        )),
        padding: EdgeInsets.only(
          left: ScreenUtil().setHeight(15),
          right: ScreenUtil().setHeight(5),
          bottom: ScreenUtil().setHeight(5),
          top: ScreenUtil().setHeight(5),
        ),
        child: TextFormField(
          decoration: new InputDecoration(
            hintText: this.widget.loc.translate("Please type your text"),
            enabledBorder: UnderlineInputBorder(
              borderSide: BorderSide(color: Colors.grey),
            ),
            focusedBorder: UnderlineInputBorder(
              borderSide: BorderSide(color: Colors.grey),
            ),
          ),
          focusNode: focusNodeText,
          style: TextStyle(fontSize: 17),
          minLines: 1,
          maxLines: 6,
          maxLength: 200,
          controller: textController,
        ),
      ),
    );
  }

  _deleteIcon(param) {
    return GestureDetector(
      onTap: () {
        setState(() {
          flag = null;
          textController.text = "";
          param == video
              ? video = null
              : images.length > 0
                  ? images.remove(images[0])
                  : {statusColor = null, statusText = null};
        });
      },
      child: Padding(
        padding: const EdgeInsets.all(3.0),
        child: CircleAvatar(
          radius: 12.0,
          backgroundColor: Colors.white,
          child: Icon(Icons.close, color: Colors.grey),
        ),
      ),
    );
  }

  _buildButton(icon, type) {
    List<dynamic> res;
    return GestureDetector(
      onTap: () async => type == "video"
          ? getVideo(MediaSource.video)
          : type == "image"
              ? loadAssets()
              : loadStatusText(),
      child: Container(
        decoration: BoxDecoration(
          shape: BoxShape.circle,
          boxShadow: [
            BoxShadow(
              color: Colors.grey,
              blurRadius: 5.0,
              spreadRadius: 1.0,
            )
          ],
        ),
        child: ClipOval(
          child: Material(
            color: Color(0xFF3DD598),
            child: InkWell(
              splashColor: Color(0xFFFCA64F),
              child: SizedBox(
                width: 60,
                height: 60,
                child: Icon(icon, size: 30.0, color: Colors.white),
              ),
            ),
          ),
        ),
      ),
    );
  }

  var contextShare;
  _onLoading(bool flag) {
    if (flag) {
      showDialog(
          context: context,
          barrierDismissible: false,
          builder: (BuildContext context) {
            contextShare = context;
            return Center(child: CircularProgressIndicator());
          });
    } else {
      // Navigator.pop(context);
      Navigator.of(contextShare).pop();
    }
    return true;
  }

  _buildSendButton() {
    var file;
    var type;
    var text;

    return GestureDetector(
      onTap: () => {
        if (images.length > 0)
          {
            file = images[0],
            type = "Photo",
            text = textController.text,
          }
        else if (video != null)
          {
            file = video,
            type = "Video",
            text = textController.text,
          }
        else if (statusColor != null && statusText != null)
          {
            file = statusColor,
            type = "Text",
            text = statusText,
          },
        _onLoading(true),
        createStory(file: file, type: type, text: text)
      },
      child: Container(
        decoration: BoxDecoration(
          shape: BoxShape.circle,
          boxShadow: [
            BoxShadow(
              color: Colors.grey,
              blurRadius: 5.0,
              spreadRadius: 1.0,
            )
          ],
        ),
        child: ClipOval(
          child: Material(
            color: Color(0xFF3DD598),
            child: InkWell(
              splashColor: Color(0xFFFCA64F),
              child: SizedBox(
                width: 60,
                height: 60,
                child: Icon(
                  Icons.send,
                  color: Colors.white,
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
