import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/screen_util.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:timeago/timeago.dart' as timeago;

class VotesPage extends StatelessWidget {
  const VotesPage(
      {Key key,
      @required this.pollOptions1VotesList,
      @required this.pollOptions2VotesList,
      @required this.pollOptions3VotesList,
      @required this.pollOptions4VotesList,
      @required this.pollOption1,
      @required this.pollOption2,
      @required this.pollOption3,
      @required this.pollOption4,
      @required this.loc})
      : super(key: key);

  final List<PollVoteModel> pollOptions1VotesList;
  final List<PollVoteModel> pollOptions2VotesList;
  final List<PollVoteModel> pollOptions3VotesList;
  final List<PollVoteModel> pollOptions4VotesList;

  final String pollOption1;
  final String pollOption2;
  final String pollOption3;
  final String pollOption4;

  final loc;

  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
      textDirection: TextDirection.ltr,
      child: ScreenUtilInit(
        designSize: Size(width, height),
        allowFontScaling: false,
        builder: () => DefaultTabController(
          length: pollOption3 == null
              ? 2
              : pollOption3 != null && pollOption4 == null
                  ? 3
                  : 4,
          child: Scaffold(
            appBar: PreferredSize(
                preferredSize: Size.fromHeight(
                  ScreenUtil().setWidth(115),
                ),
                child: AppBar(
                  backgroundColor: Color(0xFF083356),
                  leading: Padding(
                    padding: EdgeInsets.only(
                      top: ScreenUtil().setWidth(9),
                    ),
                    child: IconButton(
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      icon: Icon(Icons.arrow_back, color: Colors.white),
                    ),
                  ),
                  title: Padding(
                    padding: EdgeInsets.only(
                      left: ScreenUtil().setWidth(100),
                      top: ScreenUtil().setWidth(9),
                    ),
                    child: Text(
                      loc.translate("Votes"),
                      style: TextStyle(
                        color: Colors.white,
                      ),
                    ),
                  ),
                  bottom: PreferredSize(
                    preferredSize: tabBar.preferredSize,
                    child: Container(
                      height: ScreenUtil().setWidth(60),
                      child: ColoredBox(
                        color: Colors.white,
                        child: tabBar,
                      ),
                    ),
                  ),
                )),
            body: PreferredSize(
              preferredSize: Size.fromHeight(70.0),
              child: _buildTapBarView(
                  length: pollOption3 == null
                      ? 2
                      : pollOption3 != null && pollOption4 == null
                          ? 3
                          : 4),
            ),
          ),
        ),
      ),
    );
  }

  TabBarView _buildTapBarView({@required int length}) {
    return TabBarView(
        children: length == 2
            ? [
                _buildList(this.pollOptions1VotesList),
                _buildList(this.pollOptions2VotesList),
              ]
            : length == 3
                ? [
                    _buildList(this.pollOptions1VotesList),
                    _buildList(this.pollOptions2VotesList),
                    _buildList(this.pollOptions3VotesList),
                  ]
                : [
                    _buildList(this.pollOptions1VotesList),
                    _buildList(this.pollOptions2VotesList),
                    _buildList(this.pollOptions3VotesList),
                    _buildList(this.pollOptions4VotesList),
                  ]);
  }

  _buildList(listToShow) {
    return listToShow.length > 0
        ? ListView.builder(
            padding: EdgeInsets.all(ScreenUtil().setWidth(8)),
            itemCount: listToShow.length,
            itemBuilder: (BuildContext context, int index) {
              UserModel userData = listToShow[index].user;

              return Container(
                height: ScreenUtil().setHeight(110),
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Container(
                      margin: EdgeInsets.only(
                        top: ScreenUtil().setWidth(15),
                      ),
                      height: ScreenUtil().setWidth(200),
                      width: ScreenUtil().setWidth(60),
                      child: Stack(
                        children: <Widget>[
                          userData.profileImg == null ||
                                  userData.profileImg == "" ||
                                  userData.profileImg == "null"
                              ? DefaultProfileImg(
                                  firstName: userData.firstName,
                                  lastName: userData.lastName,
                                )
                              : ClipOval(
                                  child: Image.network(
                                    userData.profileImg,
                                    width: ScreenUtil().setWidth(38),
                                    height: ScreenUtil().setWidth(39),
                                    fit: BoxFit.cover,
                                  ),
                                ),
                        ],
                      ),
                    ),
                    Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Row(children: [
                            Container(
                              width: ScreenUtil().setWidth(220),
                              margin: EdgeInsets.only(
                                  top: ScreenUtil().setWidth(15)),
                              child: Text(
                                  userData.lastName != null &&
                                          userData.lastName != "null"
                                      ? userData.firstName.toString() +
                                          " " +
                                          userData.lastName.toString()
                                      : userData.firstName.toString(),
                                  style:
                                      TextStyle(fontWeight: FontWeight.bold)),
                            ),
                          ]),
                          Text(
                            userData.about != null && userData.about != "null"
                                ? userData.about.split('\n')[0]
                                : "",
                            style: TextStyle(
                              color: Color(0xFF98A9BC),
                              height: 2,
                            ),
                          ),
                        ]),
                  ],
                ),
              );
            })
        : Padding(
            padding: const EdgeInsets.all(50),
            child: Text(
              this.loc.translate("No votes yet..."),
              textAlign: TextAlign.center,
              style: TextStyle(
                  fontSize: ScreenUtil().setWidth(20),
                  color: Color(0xFF98A9BC)),
            ),
          );
  }

  TabBar get tabBar => TabBar(
        labelColor: Color(0xFF083356),
        unselectedLabelColor: Color(0xFF083356),
        indicatorColor: Color(0xFFE083356),
        indicatorWeight: 5,
        labelStyle: TextStyle(
            fontWeight: FontWeight.bold, fontSize: ScreenUtil().setWidth(15)),
        unselectedLabelStyle: TextStyle(
            fontWeight: FontWeight.normal, fontSize: ScreenUtil().setWidth(15)),
        tabs: pollOption3 == null
            ? [
                Tab(
                  child: Column(
                    children: [
                      Padding(
                        padding: EdgeInsets.all(
                          ScreenUtil().setWidth(2.0),
                        ),
                        child: Text(
                          this.pollOptions1VotesList.length.toString(),
                        ),
                      ),
                      Flexible(
                        fit: FlexFit.loose,
                        child: Text(
                          pollOption1,
                          softWrap: false,
                          overflow: TextOverflow.ellipsis,
                        ),
                      ),
                    ],
                  ),
                ),
                Tab(
                  child: Column(
                    children: [
                      Padding(
                        padding: EdgeInsets.all(
                          ScreenUtil().setWidth(2.0),
                        ),
                        child: Text(
                          this.pollOptions2VotesList.length.toString(),
                        ),
                      ),
                      Flexible(
                        fit: FlexFit.loose,
                        child: Text(
                          pollOption2,
                          softWrap: false,
                          overflow: TextOverflow.ellipsis,
                        ),
                      ),
                    ],
                  ),
                ),
              ]
            : pollOption3 != null && pollOption4 == null
                ? [
                    Tab(
                      child: Column(
                        children: [
                          Padding(
                            padding: EdgeInsets.all(
                              ScreenUtil().setWidth(2.0),
                            ),
                            child: Text(
                              this.pollOptions1VotesList.length.toString(),
                            ),
                          ),
                          Flexible(
                            fit: FlexFit.loose,
                            child: Text(
                              pollOption1,
                              softWrap: false,
                              overflow: TextOverflow.ellipsis,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Tab(
                      child: Column(
                        children: [
                          Padding(
                            padding: EdgeInsets.all(
                              ScreenUtil().setWidth(2.0),
                            ),
                            child: Text(
                              this.pollOptions2VotesList.length.toString(),
                            ),
                          ),
                          Flexible(
                            fit: FlexFit.loose,
                            child: Text(
                              pollOption2,
                              softWrap: false,
                              overflow: TextOverflow.ellipsis,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Tab(
                      child: Column(
                        children: [
                          Padding(
                            padding: EdgeInsets.all(
                              ScreenUtil().setWidth(2.0),
                            ),
                            child: Text(
                              this.pollOptions3VotesList.length.toString(),
                            ),
                          ),
                          Flexible(
                            fit: FlexFit.loose,
                            child: Text(
                              pollOption3,
                              softWrap: false,
                              overflow: TextOverflow.ellipsis,
                            ),
                          ),
                        ],
                      ),
                    ),
                  ]
                : [
                    Tab(
                      child: Column(
                        children: [
                          Padding(
                            padding: EdgeInsets.all(
                              ScreenUtil().setWidth(2.0),
                            ),
                            child: Text(
                              this.pollOptions1VotesList.length.toString(),
                            ),
                          ),
                          Flexible(
                            fit: FlexFit.loose,
                            child: Text(
                              pollOption1,
                              softWrap: false,
                              overflow: TextOverflow.ellipsis,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Tab(
                      child: Column(
                        children: [
                          Padding(
                            padding: EdgeInsets.all(
                              ScreenUtil().setWidth(2.0),
                            ),
                            child: Text(
                              this.pollOptions2VotesList.length.toString(),
                            ),
                          ),
                          Flexible(
                            fit: FlexFit.loose,
                            child: Text(
                              pollOption2,
                              softWrap: false,
                              overflow: TextOverflow.ellipsis,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Tab(
                      child: Column(
                        children: [
                          Padding(
                            padding: EdgeInsets.all(
                              ScreenUtil().setWidth(2.0),
                            ),
                            child: Text(
                              this.pollOptions3VotesList.length.toString(),
                            ),
                          ),
                          Flexible(
                            fit: FlexFit.loose,
                            child: Text(
                              pollOption3,
                              softWrap: false,
                              overflow: TextOverflow.ellipsis,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Tab(
                      child: Column(
                        children: [
                          Padding(
                            padding: EdgeInsets.all(
                              ScreenUtil().setWidth(2.0),
                            ),
                            child: Text(
                              this.pollOptions4VotesList.length.toString(),
                            ),
                          ),
                          Flexible(
                            fit: FlexFit.loose,
                            child: Text(
                              pollOption4,
                              softWrap: false,
                              overflow: TextOverflow.ellipsis,
                            ),
                          ),
                        ],
                      ),
                    ),
                  ],
      );
}
