import 'dart:core';
import 'dart:convert';
import 'dart:developer';
import 'package:feed_plugin/models/user_model.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:http/http.dart';
import 'package:feed_plugin/exeptions/auth_exception.dart';

class HttpService {
  // final String apiURL = 'https://feed.dev.phone.do';
  final String apiURL = 'https://feed.phone.do';
  String _jwt;

  HttpService(this._jwt);

  Future<Response> get(url, {Map<String, String> headers}) async {
    final response = await http.get(url, headers: headers);
    if (response.statusCode == 401) {
      if (json.decode(response.body)['message'] == 'Expired JWT Token') {
        throw ExpiredTokenException(response.reasonPhrase);
      } else {
        throw AuthenticateException(response.reasonPhrase);
      }
    } else {
      return response;
    }
  }

  Future<Response> post(url,
      {Map<String, String> headers, body, Encoding encoding}) async {
    final response =
        await http.post(url, headers: headers, body: body, encoding: encoding);
    if (response.statusCode == 401 &&
        json.decode(response.body)['message'] == 'Expired JWT Token') {
      throw ExpiredTokenException(response.reasonPhrase);
    } else {
      return response;
    }
  }

  Future<Response> put(url,
      {Map<String, String> headers, body, Encoding encoding}) async {
    final response =
        await http.put(url, headers: headers, body: body, encoding: encoding);
    if (response.statusCode == 401 &&
        json.decode(response.body)['message'] == 'Expired JWT Token') {
      throw ExpiredTokenException(response.reasonPhrase);
    } else {
      return response;
    }
  }

  Future<http.Response> fetchUser(id) {
    final userId = id;
    return get(Uri.parse('$apiURL/users/getById?id=$userId'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchAllPosts() {
    return get(Uri.parse('$apiURL/posts/all'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchPostsByUserId(id) async {
    return get(Uri.parse('$apiURL/posts/byUserId?user=$id'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchFavoritePosts(currentUserId, saveId) async {
    return get(
        Uri.parse(
            '$apiURL/reports/favorite?user=$currentUserId&saveId=$saveId'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> fetchCommentsByPostId(postId) async {
    return get(Uri.parse('$apiURL/post-comments/byPostId?post=$postId'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> addPost({
    @required UserModel user,
    @required String title,
    @required String description,
    @required String type,
    String attachedUrl,
    int pollQuestionId,
  }) {
    var data = json.encode({
      "user": user.id,
      "description": description,
      "type": type,
      "attachedUrl": attachedUrl,
      "title": title,
      "pollQuestion": pollQuestionId
    });
    log(data);

    return post(Uri.parse('$apiURL/posts/create'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> uploadComment({
    @required int userId,
    @required int postId,
    @required String comment,
  }) {
    var data = json.encode({
      "user": userId,
      "post": postId,
      "comment": comment,
    });
    log(data);

    return post(Uri.parse('$apiURL/post-comments/create'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> fetchAllReports() {
    return get(Uri.parse('$apiURL/report-types/all'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchSubReport(reportTypeId) async {
    return get(
        Uri.parse(
            '$apiURL/report-sub-types/byReportTypeId?reportType=$reportTypeId'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> fetchReportByPostId(id) async {
    return await get(Uri.parse('$apiURL/reports/byPostId?post=$id'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> addReport(
      {@required int typeId, @required int userId, @required int postId}) {
    var data = json.encode({"type": typeId, "user": userId, "post": postId});
    log(data);
    return post(Uri.parse('$apiURL/reports/create'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> updatePostReport({@required int postId}) {
    return put(Uri.parse('$apiURL/posts/reports?post=$postId'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
      "content-type": 'application/json',
    });
  }

  Future<http.Response> removeReport({@required reportId}) {
    return delete(Uri.parse('$apiURL/reports/remove?id=$reportId'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> removeComment({@required commentId}) {
    return delete(Uri.parse('$apiURL/post-comments/remove?id=$commentId'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> fetchAllSubType() {
    return get(Uri.parse('$apiURL/report-sub-types/all'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> authenticateUser(
      {@required firstName,
      @required lastName,
      @required about,
      @required profileImg,
      @required token,
      partnerId}) {
    return get(
        Uri.parse(
            '$apiURL/users/authenticate?firstName=$firstName&lastName=$lastName&about=$about&profileImg=$profileImg&token=$token&partnerId=$partnerId'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> updateUserMedia(
      {@required socialMedia, @required userId}) {
    var media = json.decode(socialMedia);
    var data = json.encode({
      "userId": userId,
      "socialMedia": media,
    });
    return put(Uri.parse('$apiURL/users/update'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> removePost({@required postId}) {
    return delete(Uri.parse('$apiURL/posts/remove?post=$postId'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> addhashtagPosts({
    @required int tagId,
    @required int postId,
  }) {
    var data = json.encode({
      "tag": tagId,
      "post": postId,
    });
    log(data);

    return post(Uri.parse('$apiURL/hashtagPosts/create'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> addNewhashtag({
    @required String tagName,
  }) {
    var data = json.encode({
      "tagName": tagName,
    });
    log(data);

    return post(Uri.parse('$apiURL/hashtag/create'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> getAllHashtags() {
    return get(Uri.parse('$apiURL/hashtag/all'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> getHashtagByTagName(tagName) async {
    return get(Uri.parse('$apiURL/hashtagPosts/byTagName?tagName=%23$tagName'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> getUsersRandom(skip) async {
    return get(Uri.parse('$apiURL/users/getRnd?skip=$skip'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> addReplyComment({
    @required int postComments,
    @required int user,
    @required String comment,
  }) {
    var data = json.encode({
      "postComments": postComments,
      "user": user,
      "comment": comment,
    });

    return post(Uri.parse('$apiURL/reply-comments/create'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> getReplayCommentsList() async {
    return get(Uri.parse('$apiURL/reply-comments/all'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> removeReplyComment({@required replyId}) {
    return delete(Uri.parse('$apiURL/reply-comments/remove?id=$replyId'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> createPollQuestion({
    @required String question,
  }) {
    var data = json.encode({
      "question": question,
    });
    log(data);

    return post(Uri.parse('$apiURL/poll-questions/create'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> createPollOption({
    @required int pollQuestion,
    @required String option,
  }) {
    var data = json.encode({"pollQuestion": pollQuestion, "option": option});
    log(data);

    return post(Uri.parse('$apiURL/poll-options/create'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> fetchAllPollVotes() {
    return get(Uri.parse('$apiURL/poll-votes/all'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> getAllOptions() {
    return get(Uri.parse('$apiURL/poll-options/all'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> getOptionsByQuestionId(questionId) async {
    return get(
        Uri.parse('$apiURL/poll-options/byQuestionId?question=$questionId'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> createPollVote({
    @required int pollOption,
    @required int user,
  }) {
    var data = json.encode({"pollOption": pollOption, "user": user});
    log(data);

    return post(Uri.parse('$apiURL/poll-votes/create'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> removePollVote({@required pollVoteId}) {
    return delete(Uri.parse('$apiURL/poll-votes/remove?id=$pollVoteId'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> getAllVotes() {
    return get(Uri.parse('$apiURL/poll-votes/all'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> getVotesByOptionId(optionId) async {
    return get(Uri.parse('$apiURL/poll-votes/byOptionId?option=$optionId'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> getAllStories() {
    return get(Uri.parse('$apiURL/story/all'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> createStory({
    @required String text,
    @required String attachedUrl,
    @required int user,
    @required String type,
  }) {
    var data = json.encode(
        {"text": text, "attachedUrl": attachedUrl, "user": user, "type": type});

    return post(Uri.parse('$apiURL/story/create'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> updateStory({
    @required int storyId,
    @required String attachedUrl,
    @required String text,
    @required String type,
  }) {
    return put(
        Uri.parse(
            '$apiURL/story/updateAttachedUrl?id=$storyId&attachedUrl=$attachedUrl&text=$text&type=$type'),
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        });
  }

  Future<http.Response> removeStory({@required storyId}) {
    return delete(Uri.parse('$apiURL/story/remove?id=$storyId'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }
}
