import 'package:feed_plugin/pages/my_feed.dart';
import 'package:feed_plugin/utilities/colors.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';

class BusinessProfilePage extends StatefulWidget {
  BusinessProfilePage({Key key, this.loc}) : super(key: key);

  final loc;

  @override
  _BusinessProfilePageState createState() => _BusinessProfilePageState();
}

class _BusinessProfilePageState extends State<BusinessProfilePage> {
  List<String> titles = [
    "Calls",
    "Leads",
    "Sales",
    "Messages",
    "Open Issues",
    "Meetings",
  ];

  List<String> subTitles = [
    "150",
    "10",
    "24",
    "8",
    "0",
    "3",
  ];

  List<int> colors = [
    0xFF0062FF,
    0xFF50B5FF,
    0xFFA461D8,
    0xFF3DD598,
    0xFFFFC5A5A,
    0xFFFFC542,
  ];

  List<Icon> icons = [
    Icon(
      Icons.local_phone_outlined,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.person_outline,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.monetization_on_outlined,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.mail_outline,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.lock_open,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.date_range_outlined,
      color: Color(0xFF083356),
      size: 30,
    ),
  ];

  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
      textDirection: TextDirection.ltr,
      child: ScreenUtilInit(
        designSize: Size(width, height),
        builder: () => Scaffold(
          appBar: PreferredSize(
              preferredSize: Size.fromHeight(70.0),
              child: AppBar(
                  backgroundColor: Color(0xFF083356),
                  leading: _buildBackButton(context),
                  title: _buildTitle(),
                  actions: <Widget>[
                    _buildPersonButton(),
                  ])),
          body: _buildBody(),
        ),
      ),
    );
  }

  _buildBackButton(context) {
    return Padding(
      padding: EdgeInsets.only(top: ScreenUtil().setWidth(10)),
      child: IconButton(
          icon: Icon(
            Icons.arrow_back,
          ),
          onPressed: () {
            Navigator.pop(
              context,
              MyFeedPage(
                currentUser: null,
                dislikeId: null,
                loc: null,
                likeId: null,
                pollOptionsList: [],
                saveId: null,
                postsList1: [],
                withPartner: true,
              ),
            );
          }),
    );
  }

  _buildTitle() {
    return Padding(
      padding: EdgeInsets.only(top: ScreenUtil().setWidth(10)),
      child: Center(
          child: Text(
        widget.loc.translate("Activities"),
        style: TextStyle(color: Colors.white),
      )),
    );
  }

  _buildPersonButton() {
    return Padding(
      padding: EdgeInsets.only(
          right: ScreenUtil().setWidth(10), top: ScreenUtil().setWidth(8)),
      child: IconButton(
          icon: Icon(
            Icons.person_pin,
            size: 40,
          ),
          onPressed: () {}),
    );
  }

  _buildBody() {
    return ListView.builder(
      itemCount: 6,
      itemBuilder: (context, index) {
        return _buildItem(index);
      },
    );
  }

  _buildItem(int index) {
    return ClipRRect(
      borderRadius: BorderRadius.circular(ScreenUtil().setWidth(20)),
      child: Container(
        margin: EdgeInsets.only(left: 10, top: 5, right: 10, bottom: 5),
        child: ClipPath(
          clipper: ShapeBorderClipper(
              shape: RoundedRectangleBorder(
                  borderRadius:
                      BorderRadius.circular(ScreenUtil().setWidth(17)))),
          child: _buildCard(index),
        ),
      ),
    );
  }

  _buildCard(int index) {
    return Card(
      elevation: 2,
      shape: Border(
          top: BorderSide(
              color: appLightGreyBg, width: ScreenUtil().setWidth(2)),
          right: BorderSide(
              color: appLightGreyBg, width: ScreenUtil().setWidth(2)),
          left: BorderSide(
              color: Color(colors[index]), width: ScreenUtil().setWidth(6))),
      child: Padding(
        padding: EdgeInsets.all(ScreenUtil().setWidth(13)),
        child: ListTile(
          leading: Container(
            height: ScreenUtil().setWidth(40),
            width: ScreenUtil().setWidth(40),
            child: ClipRRect(
              borderRadius: BorderRadius.circular(ScreenUtil().setWidth(8)),
              child: Container(
                color: Color(0xE8ECEFE8ECEF),
                child: (icons[index]),
              ),
            ),
          ),
          title: Text(
            widget.loc.translate(titles[index]),
            overflow: TextOverflow.ellipsis,
            style: TextStyle(
              color: Color(colors[index]),
              fontWeight: FontWeight.bold,
              fontSize: ScreenUtil().setSp(20),
            ),
          ),
          subtitle: Padding(
            padding: EdgeInsets.only(top: ScreenUtil().setWidth(5)),
            child: Text(
              widget.loc.translate("You have ") +
                  subTitles[index] +
                  (" ") +
                  widget.loc.translate(titles[index]),
              style: TextStyle(
                color: Color(0xFF083356),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
