import 'package:feed_plugin/models/hashtagPostsModel.dart';
import 'package:feed_plugin/models/poll_option_model.dart';
import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/pages/hashtag_posts.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_parsed_text/flutter_parsed_text.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:url_launcher/url_launcher.dart' show canLaunch, launch;

class Parse extends StatefulWidget {
  const Parse({
    Key key,
    @required this.myText,
    @required this.style,
    @required this.loc,
    @required this.currentUser,
    @required this.pollOptionsList,
    @required this.pollVotesList,
  }) : super(key: key);

  final String myText;
  final TextStyle style;
  final loc;
  final UserModel currentUser;
  final List<PollOptionModel> pollOptionsList;
  final List<PollVoteModel> pollVotesList;

  @override
  _ParseState createState() => _ParseState();
}

class _ParseState extends State<Parse> {
  HttpService httpService;
  FeedRepository feedRepository;
  List<HashtagPostsModel> tagPosts = [];

  @override
  void initState() {
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return ParsedText(
      alignment: TextAlign.start,
      text: this.widget.myText,
      parse: <MatchText>[
        MatchText(
            type: ParsedType.EMAIL,
            style: TextStyle(
              color: Colors.blue,
              fontSize: ScreenUtil().setSp(15),
            ),
            onTap: (url) {
              launch("mailto:" + url);
            }),
        MatchText(
            type: ParsedType.URL,
            style: TextStyle(
              color: Colors.blue,
              fontSize: ScreenUtil().setSp(15),
            ),
            onTap: (url) async {
              var a = await canLaunch(url);

              if (a) {
                launch(url);
              }
            }),
        MatchText(
            type: ParsedType.PHONE,
            style: TextStyle(
              color: Colors.blue,
              fontSize: ScreenUtil().setSp(15),
            ),
            onTap: (url) {
              launch("tel:" + url);
            }),
        MatchText(
            pattern: r"\B#+([\w]+)\b",
            style: TextStyle(
              color: Colors.blue,
              fontSize: ScreenUtil().setSp(15),
            ),
            onTap: (url) async {
              feedRepository
                  .getHashtagPostByTagName(url.toString())
                  .then((value) async => {
                        FutureBuilder(
                            future: await Navigator.push(
                              context,
                              new MaterialPageRoute(
                                builder: (context) => HashtagPosts(
                                  hashtagPostsData: value,
                                  loc: widget.loc,
                                  currentUser: widget.currentUser,
                                  pollOptionsList: this.widget.pollOptionsList,
                                  pollVotesList: this.widget.pollVotesList,
                                ),
                              ),
                            ),
                            builder:
                                (context, AsyncSnapshot<dynamic> snapshot) {
                              if (snapshot.connectionState ==
                                      ConnectionState.waiting ||
                                  snapshot.hasError) {
                                return CircularProgressIndicator();
                              }
                              return Container();
                            })
                      });
            }),
        MatchText(
            pattern: r"lon",
            style: TextStyle(
              color: Colors.blue,
              fontSize: ScreenUtil().setSp(15),
            ),
            onTap: (url) async {})
      ],
      style: this.widget.style,
    );
  }
}
