import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/report_sub_type_model.dart';
import 'package:feed_plugin/models/report_type_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:status_alert/status_alert.dart';

List<ReportTypeModel> reportsList = [];
List<ReportSubTypeModel> reportsSubTypesList = [];
int flagState = 0;

HttpService httpService;
FeedRepository feedRepository;

class Reports extends StatefulWidget {
  const Reports({
    Key key,
    @required this.postData,
    @required this.currentUser,
    @required this.loc,
  }) : super(key: key);

  final PostModel postData;
  final UserModel currentUser;
  final loc;
  @override
  _ReportsState createState() => _ReportsState();
}

class _ReportsState extends State<Reports> {
  HttpService httpService;
  FeedRepository feedRepository;

  void initState() {
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    super.initState();
  }

  Future<void> reportPost(subTypeId) async {
    await feedRepository.addReport(
        subTypeId, this.widget.currentUser.id, this.widget.postData.id);
    await feedRepository.updatePostReport(this.widget.postData.id);
  }

  Future<List<ReportTypeModel>> getReportsList() async {
    reportsList = await feedRepository.fetchAllReports();
    return reportsList;
  }

  Future<List<ReportSubTypeModel>> getSubTypesReportsList() async {
    reportsSubTypesList = await feedRepository.fetchSubReport(flagState);
    return reportsSubTypesList;
  }

  Widget build(BuildContext context) {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: FutureBuilder(
        future: getReportsList(),
        builder: (context, reportSnap) {
          if (reportSnap.connectionState == ConnectionState.waiting ||
              reportSnap.connectionState == ConnectionState.none) {
            return Center(child: CircularProgressIndicator());
          }
          return FutureBuilder(
              future: getSubTypesReportsList(),
              builder: (context, reportSubSnap) {
                if (reportSubSnap.connectionState == ConnectionState.waiting ||
                    reportSubSnap.connectionState == ConnectionState.none) {
                  return Center(child: CircularProgressIndicator());
                }

                return AlertDialog(
                    contentPadding: EdgeInsets.fromLTRB(
                        ScreenUtil().setSp(3),
                        ScreenUtil().setSp(3),
                        ScreenUtil().setSp(2),
                        ScreenUtil().setSp(15)),
                    title: Column(
                      children: [
                        Row(
                          children: [
                            flagState != 0
                                ? Column(
                                    crossAxisAlignment: CrossAxisAlignment.end,
                                    children: [
                                      TextButton(
                                        child: Container(
                                          margin: EdgeInsets.only(
                                              bottom: ScreenUtil().setSp(30)),
                                          alignment: Alignment.topLeft,
                                          width: ScreenUtil().setWidth(125),
                                          child: Icon(
                                            Icons.chevron_left,
                                            color: Colors.black,
                                          ),
                                        ),
                                        onPressed: () {
                                          setState(() {
                                            flagState = 0;
                                            setState(() {});
                                          });
                                          setupAlertDialoadContainer();
                                        },
                                      ),
                                    ],
                                  )
                                : Container(
                                    alignment: Alignment.centerLeft,
                                    width: ScreenUtil().setWidth(140),
                                  ),
                            Column(
                              children: [
                                TextButton(
                                  child: Container(
                                    margin: EdgeInsets.only(
                                        bottom: ScreenUtil().setSp(30)),
                                    width: ScreenUtil().setSp(80),
                                    child: Icon(
                                      Icons.close,
                                      color: Colors.black,
                                    ),
                                  ),
                                  onPressed: () {
                                    setState(() {
                                      flagState = 0;
                                      setState(() {});
                                    });
                                    Navigator.of(context).pop();
                                  },
                                ),
                              ],
                            ),
                          ],
                        ),
                        flagState == 0
                            ? Container(
                                width: ScreenUtil().setWidth(280),
                                child: Text(
                                  this
                                      .widget
                                      .loc
                                      .translate('why are you reporting this?'),
                                  style: TextStyle(
                                      color: Colors.black,
                                      fontSize: ScreenUtil().setSp(20)),
                                ))
                            : Container(
                                width: ScreenUtil().setWidth(280),
                                child: Text(
                                  this
                                      .widget
                                      .loc
                                      .translate('Tell us a little more'),
                                  style: TextStyle(
                                      color: Colors.black,
                                      fontSize: ScreenUtil().setSp(20)),
                                ),
                              ),
                        Divider(
                          indent: 7,
                          endIndent: 2,
                          height: ScreenUtil().setSp(20),
                          color: Colors.black,
                        ),
                      ],
                    ),
                    content: (flagState == 0)
                        ? setupAlertDialoadContainer()
                        : setupAlertSubReportsTyps());
              });
        },
      ),
    );
  }

  setupAlertDialoadContainer() {
    return Container(
      height: 160.0,
      width: 160.0,
      child: ListView.builder(
        itemCount: reportsList.length,
        itemBuilder: (BuildContext context, int index) {
          return (reportsList[index].type == "Likes")
              ? Text("")
              : Row(
                  children: [
                    GestureDetector(
                      onTap: () {
                        setState(() {
                          flagState = reportsList[index].id;
                        });
                      },
                      child: Container(
                        height: ScreenUtil().setHeight(50),
                        child: Padding(
                          padding:
                              EdgeInsets.only(left: ScreenUtil().setSp(16)),
                          child: Text(
                            this.widget.loc.translate("I think it’s ") +
                                this.widget.loc.translate(
                                    reportsList[index].type.toString()),
                            style: TextStyle(
                                color: Colors.black,
                                fontSize: ScreenUtil().setSp(17)),
                          ),
                        ),
                      ),
                    ),
                  ],
                );
        },
      ),
    );
  }

  Widget setupAlertSubReportsTyps() {
    return Container(
      height: 160.0,
      width: 160.0,
      margin: EdgeInsets.only(right: 16),
      child: Scrollbar(
        isAlwaysShown: true,
        child: ListView.builder(
          itemCount: reportsSubTypesList.length,
          itemBuilder: (BuildContext context, int index) {
            return Row(
              children: [
                Container(
                    child: GestureDetector(
                  onTap: () {
                    StatusAlert.show(
                      context,
                      duration: Duration(seconds: 2),
                      title:
                          this.widget.loc.translate('Thanks for your Report'),
                      configuration: IconConfiguration(
                        icon: Icons.add_moderator,
                        size: 50,
                      ),
                    );
                    flagState = 0;
                    reportPost(reportsSubTypesList[index].id)
                        .then((value) => {Navigator.of(context).pop(false)});
                  },
                  child: Container(
                    padding: EdgeInsets.only(left: 16),
                    child: Text(
                      this.widget.loc.translate(
                          reportsSubTypesList[index].type.toString()),
                      style: TextStyle(
                          color: Colors.black,
                          fontSize: ScreenUtil().setSp(15)),
                    ),
                  ),
                )),
              ],
            );
          },
        ),
      ),
    );
  }
}
