import 'dart:io';
import 'dart:typed_data';
import 'dart:ui';

import 'package:feed_plugin/models/poll_option_model.dart';
import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/models/replyCommentModel.dart';
import 'package:feed_plugin/pages/comments/screens/chat.dart';
import 'package:feed_plugin/pages/hashtag_posts.dart';
import 'package:feed_plugin/pages/likes_and_dislikes.dart';
import 'package:feed_plugin/pages/votes_page.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:feed_plugin/widgets/photo_grid.dart';
import 'package:feed_plugin/widgets/videoB.dart';
import 'package:flutter/foundation.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/report_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/pages/user_posts.dart';
import 'package:feed_plugin/widgets/popup.dart';
import 'package:flutter_parsed_text/flutter_parsed_text.dart';

import 'package:timeago/timeago.dart' as timeago;
import 'package:flutter/material.dart';
import 'package:pk_skeleton/pk_skeleton.dart';

import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:number_display/number_display.dart';
import 'package:status_alert/status_alert.dart';

import 'package:flutter_share/flutter_share.dart';
import 'package:feed_plugin/pages/video&picture.dart';
import 'package:url_launcher/url_launcher.dart';

final display = createDisplay(
  length: 4,
  separator: ',',
  decimal: 2,
);

class FeedPost extends StatefulWidget {
  const FeedPost({
    Key key,
    @required this.postData,
    @required this.currentUser,
    @required this.likeId,
    @required this.dislikeId,
    @required this.saveId,
    @required this.images,
    @required this.commentsLength,
    @required this.postsList,
    @required this.pollOptionsList,
    @required this.generalPollOptionsList,
    @required this.pollVotesList,
    @required this.loc,
    this.play,
  }) : super(key: key);

  final PostModel postData;
  final UserModel currentUser;
  final int likeId;
  final int dislikeId;
  final int saveId;
  final bool play;
  final List<String> images;
  final int commentsLength;
  final List<PostModel> postsList;
  final List<PollOptionModel> pollOptionsList;
  final List<PollOptionModel> generalPollOptionsList;
  final List<PollVoteModel> pollVotesList;

  final loc;
  @override
  _FeedPostState createState() => _FeedPostState();
}

class _FeedPostState extends State<FeedPost> {
  HttpService httpService;
  FeedRepository feedRepository;

  List<ReportModel> likesList;
  List<ReportModel> dislikesList;

  bool mySave;
  bool myLike;
  bool myDislike;
  bool flagReport = true;

  int commentsOnPost;

  int reportLikeId = 0;
  int reportDislikeId = 0;
  int reportSaveId = 0;

  UserModel userData;

  String firstHalf;
  String secondHalf;
  bool flag = true;

  var contextShare;

  List<ReplyCommentModel> replyCommentsList;

  bool isPollResult;
  int pollVotesListLength;
  List<PollVoteModel> pollVotesList;
  List<PollVoteModel> pollOptions1VotesList;
  List<PollVoteModel> pollOptions2VotesList;
  List<PollVoteModel> pollOptions3VotesList;
  List<PollVoteModel> pollOptions4VotesList;

  int pollOptions1VotesListLength;
  int pollOptions2VotesListLength;
  int pollOptions3VotesListLength;
  int pollOptions4VotesListLength;

  PollVoteModel voteToRemove;
  List<String> percent;
  bool _clicked = false;

  @override
  void initState() {
    percent = [];
    pollVotesListLength = 0;
    pollVotesList = [];
    pollOptions1VotesListLength = 0;
    pollOptions2VotesListLength = 0;
    pollOptions3VotesListLength = 0;
    pollOptions4VotesListLength = 0;

    pollOptions1VotesList = [];
    pollOptions2VotesList = [];
    pollOptions3VotesList = [];
    pollOptions4VotesList = [];

    isPollResult = false;
    if (widget.pollOptionsList != null &&
        widget.pollOptionsList.length > 0 &&
        widget.postData.pollQuestion != null &&
        widget.pollVotesList.length > 0 &&
        widget.pollVotesList != null) {
      if (pollVotesList.length == 0) {
        pollVotesList = this.widget.pollVotesList;
      }

      pollVotesListLength = pollVotesList.length;
      if (pollVotesList.where(
            (item) => item.user.id == this.widget.currentUser.id,
          ) !=
          null) {
        isPollResult = true;
      } else {
        isPollResult = false;
      }

      if (isPollResult == true) {
        for (var i = 0; i < pollVotesList.length; i++) {
          if (pollVotesList[i].pollOption.id == widget.pollOptionsList[0].id) {
            pollOptions1VotesList.add(pollVotesList[i]);
          } else if (pollVotesList[i].pollOption.id ==
              widget.pollOptionsList[1].id) {
            pollOptions2VotesList.add(pollVotesList[i]);
          } else if (widget.pollOptionsList.length > 2) {
            if (pollVotesList[i].pollOption.id ==
                widget.pollOptionsList[2].id) {
              pollOptions3VotesList.add(pollVotesList[i]);
            }
            if (widget.pollOptionsList.length > 3) {
              if (pollVotesList[i].pollOption.id ==
                  widget.pollOptionsList[3].id) {
                pollOptions4VotesList.add(pollVotesList[i]);
              }
            }
          }
        }
        voteToRemove = pollVotesList.firstWhere(
            (item) => item.user.id == this.widget.currentUser.id,
            orElse: () => null);
      }
      if (voteToRemove != null) {
        isPollResult = true;
      } else {
        isPollResult = false;
      }

      pollOptions1VotesListLength =
          pollOptions1VotesList.length > 0 ? pollOptions1VotesList.length : 0;
      pollOptions2VotesListLength =
          pollOptions2VotesList.length > 0 ? pollOptions2VotesList.length : 0;
      pollOptions3VotesListLength =
          pollOptions3VotesList.length > 0 ? pollOptions3VotesList.length : 0;
      pollOptions4VotesListLength =
          pollOptions4VotesList.length > 0 ? pollOptions4VotesList.length : 0;
    }

    likesList = [];
    dislikesList = [];

    mySave = false;
    myLike = false;
    myDislike = false;

    commentsOnPost = 0;
    userData = this.widget.postData.user;
    replyCommentsList = [];

    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);

    if (widget.postData.description.length > 241) {
      firstHalf = widget.postData.description.substring(0, 241);
      secondHalf = widget.postData.description
          .substring(241, widget.postData.description.length);
    } else {
      firstHalf = widget.postData.description;
      secondHalf = "";
    }

    getLikesListByPostId(this.widget.postData.id).then(
      (data) async {
        await getPostComments();
      },
    );

    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  Future<List<ReplyCommentModel>> getReplayCommentsList() async {
    replyCommentsList = await feedRepository.getReplayCommentsList();
    return replyCommentsList;
  }

  Future<void> getLikesListByPostId(postId) async {
    List<ReportModel> reportsLikeList = [];
    List<ReportModel> reportsDislikeList = [];
    List<ReportModel> reportsSaveList = [];

    bool isDislike = false;
    bool isLike = false;
    bool isSave = false;

    await feedRepository.fetchPostReports(postId).then((reportsList) => {
          reportsList.forEach((e) {
            if (e.type?.id == this.widget.likeId) {
              reportsLikeList.add(e);
              if (e.user.id == this.widget.currentUser.id) {
                isLike = true;
                reportLikeId = e.id;
              }
            } else if (e.type?.id == this.widget.dislikeId) {
              reportsDislikeList.add(e);
              if (e.user.id == this.widget.currentUser.id) {
                isDislike = true;
                reportDislikeId = e.id;
              }
            } else if (e.type?.id == this.widget.saveId) {
              reportsSaveList.add(e);
              if (e.user.id == this.widget.currentUser.id) {
                isSave = true;
                reportSaveId = e.id;
              }
            } else {
              if (e.user.id == this.widget.currentUser.id) {
                if (mounted) {
                  this.setState(() {
                    flagReport = false;
                  });
                }
              }
            }
          }),
          if (mounted)
            {
              this.setState(() {
                likesList = reportsLikeList;
                dislikesList = reportsDislikeList;
                myLike = isLike;
                myDislike = isDislike;
                mySave = isSave;
              })
            }
        });
  }

  getPostComments() async {
    List<ReplyCommentModel> reply = [];
    await feedRepository
        .fetchPostComments(this.widget.postData.id)
        .then((comments) => {
              getReplayCommentsList().then((replyC) async => {
                    if (replyC != null)
                      {
                        reply = replyC
                            .where((item) =>
                                item.postComments.post.id == widget.postData.id)
                            .toList(),
                      },
                    if (mounted)
                      {
                        setState(
                          () {
                            commentsOnPost = comments.length + reply.length;
                          },
                        )
                      },
                  })
            });
  }

  Future<void> removeReportPost(reportId, subTypeId) async {
    List<ReportModel> dislikes = [];
    List<ReportModel> likes = [];
    await feedRepository.removeReport(reportId).then((value) => {
          if (subTypeId == this.widget.likeId)
            {
              likesList.forEach((like) {
                if (like.id != reportId) {
                  likes.add(like);
                }
              }),
              setState(() {
                likesList = likes;
              }),
            }
          else if (subTypeId == this.widget.dislikeId)
            {
              dislikesList.forEach((dislike) {
                if (dislike.id != reportId) {
                  dislikes.add(dislike);
                }
              }),
              setState(() {
                dislikesList = dislikes;
              }),
            }
        });
  }

  Future<void> reportPost(subTypeId) async {
    await feedRepository
        .addReport(
            subTypeId, this.widget.currentUser.id, this.widget.postData.id)
        .then((data) => {
              if (subTypeId == this.widget.likeId)
                {
                  setState(() {
                    reportLikeId = data.id;
                    likesList.add(data);
                  }),
                }
              else
                {
                  if (subTypeId == this.widget.dislikeId)
                    {
                      setState(() {
                        reportDislikeId = data.id;
                        dislikesList.add(data);
                      }),
                    }
                  else
                    {
                      if (subTypeId == this.widget.saveId)
                        {
                          reportSaveId = data.id,
                        }
                    }
                }
            });
  }

  Future<void> show() async {
    StatusAlert.show(
      context,
      duration: Duration(seconds: 2),
      title: this.widget.loc.translate('Save post'),
      subtitle: this.widget.loc.translate('this post saved for later'),
      configuration: IconConfiguration(
        icon: Icons.favorite_border_rounded,
        size: 80,
      ),
    );
    await reportPost(this.widget.saveId);
  }

  _onLoading(bool flag) {
    if (flag) {
      showDialog(
          context: context,
          barrierDismissible: false,
          builder: (BuildContext context) {
            contextShare = context;
            return Center(child: CircularProgressIndicator());
          });
    } else {
      if (contextShare != null) {
        Navigator.of(contextShare).pop();
      } else {
        Navigator.of(context).pop();
      }
    }
  }

  removeUserPost() {
    showDialog(
        context: context,
        barrierDismissible: false,
        builder: (BuildContext context1) {
          return AlertDialog(
            content: Text(this
                .widget
                .loc
                .translate("Are you sure you want to delete this post?")),
            actions: [
              TextButton(
                onPressed: () {
                  Navigator.of(context).pop();
                },
                child: Text(this.widget.loc.translate("Cancel")),
              ),
              TextButton(
                onPressed: () {
                  feedRepository
                      .removePost(this.widget.postData.id)
                      .then((value) => {
                            Navigator.of(context).pop(),
                          });
                },
                child: Text(this.widget.loc.translate("Ok")),
              ),
            ],
          );
        }).then((value) => {Navigator.of(context).pop()});
  }

  Future<void> shareText({title, String text}) async {
    await FlutterShare.share(title: title, text: text);
  }

  Future<void> shareFile({
    String title,
    String text,
    String filePath,
  }) async {
    await FlutterShare.share(
      title: title,
      text: text,
      linkUrl: filePath,
    );
  }

  Future<void> share(title, description, attachedUrl, user) async {
    if (this.widget.postData.type == "Photo") {
      String filePath = attachedUrl.toString().replaceAll('*', "\n\n");
      shareFile(
        title: title,
        text: title + "\n" + description,
        filePath: filePath,
      );
    } else if (this.widget.postData.type == "Video") {
      shareFile(
        title: title,
        text: title + "\n" + description,
        filePath: attachedUrl,
      );
    } else {
      if (widget.postData.pollQuestion == null) {
        shareText(text: title + "\n" + description, title: title);
      } else {
        var text = title +
            "\n" +
            description +
            "\n" +
            "\n" +
            widget.postData.pollQuestion.question.toString() +
            "\n";
        for (var i = 0; i < widget.pollOptionsList.length; i++) {
          text += (i + 1).toString() +
              ". " +
              widget.pollOptionsList[i].option.toString() +
              " - " +
              (percent.length > 0 ? percent[i] : '0%') +
              "\n";
        }
        shareText(text: text, title: title);
      }
    }
  }

  dynamic checkIsHebrew(String text) {
    var enLen;
    var heLen;
    if (text.contains(new RegExp(r'[א-ת]'))) {
      enLen = text.trim().replaceAll(new RegExp(r'[א-ת]'), '').length;
      heLen = text.trim().replaceAll(new RegExp(r'[^א-ת]'), '').length;
      if (enLen < heLen) {
        return true;
      }
    }
    return false;
  }

  @override
  Widget build(BuildContext context) {
    final date2 = DateTime.now();
    final difference =
        date2.difference(this.widget.postData.createdAt).inMinutes;
    final fifteenAgo =
        new DateTime.now().subtract(new Duration(minutes: difference));

    return likesList == []
        ? Directionality(
            textDirection: TextDirection.ltr,
            child: PKCardSkeleton(
              isCircularImage: true,
              isBottomLinesActive: true,
            ),
          )
        : Directionality(
            textDirection: TextDirection.ltr,
            child: Container(
                color: Colors.white,
                margin: EdgeInsets.only(bottom: ScreenUtil().setHeight(10)),
                child: userData == null
                    ? PKCardSkeleton(
                        isCircularImage: true,
                        isBottomLinesActive: true,
                      )
                    : Container(
                        padding: EdgeInsets.symmetric(
                            horizontal: ScreenUtil().setWidth(1.0)),
                        margin: EdgeInsets.only(
                            top: ScreenUtil().setWidth(23.0),
                            bottom: ScreenUtil().setWidth(8)),
                        child: Column(
                            mainAxisAlignment: MainAxisAlignment.center,
                            children: <Widget>[
                              Row(
                                children: [
                                  Expanded(
                                      flex: 1, child: _buildProfileImage()),
                                  Expanded(
                                      flex: 5,
                                      child: _buildProfileDetails(fifteenAgo)),
                                  Expanded(
                                    child: _buildMoreIcon(),
                                  )
                                ],
                              ),
                              _buildPostText(),
                              _buildPoll(),
                              this.widget.postData.attachedUrl == "null" &&
                                      this.widget.postData.type != null
                                  ? Text(
                                      this.widget.loc.translate(
                                          "The file was not uploaded successfully"),
                                      style: TextStyle(
                                          fontSize: ScreenUtil().setHeight(15),
                                          color: Colors.grey),
                                    )
                                  : _buildPostAttached(),
                              Divider(
                                color: Color(0xff98A9BC),
                              ),
                              Container(
                                margin: EdgeInsets.only(
                                    right: ScreenUtil().setWidth(12.0),
                                    left: ScreenUtil().setWidth(12.0)),
                                child: Row(
                                  children: [
                                    Expanded(child: _buildShowComments()),
                                    Expanded(child: _buildShowLikes()),
                                  ],
                                ),
                              ),
                              Divider(
                                color: Color(0xff98A9BC),
                              ),
                              _buildButtomBar()
                            ]))),
          );
  }

  _buildProfileImage() {
    return Container(
      margin: EdgeInsets.only(left: ScreenUtil().setWidth(12.0)),
      child: GestureDetector(
        onTap: () {
          List<PostModel> userPosts = this
              .widget
              .postsList
              .where((p) => p.user.id == this.widget.postData.user.id)
              .toList();
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => UserPost(
                userData: userData,
                currentUser: this.widget.currentUser,
                userPosts: userPosts,
                pollOptionsList: widget.generalPollOptionsList,
                pollVotesList: pollVotesList,
                loc: this.widget.loc,
              ),
            ),
          );
        },
        child: userData.profileImg == null ||
                userData.profileImg == "" ||
                userData.profileImg == "null"
            ? DefaultProfileImg(
                firstName: userData.firstName,
                lastName: userData.lastName,
              )
            : ClipOval(
                child: Image.network(
                  userData.profileImg,
                  width: ScreenUtil().setWidth(40),
                  height: ScreenUtil().setWidth(50),
                  fit: BoxFit.cover,
                ),
              ),
      ),
    );
  }

  _buildProfileDetails(fifteenAgo) {
    return Container(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Container(
            width: ScreenUtil().setWidth(250),
            margin: EdgeInsets.only(left: ScreenUtil().setWidth(10.0)),
            child: Text(
              userData.lastName != "null"
                  ? userData.firstName + " " + userData.lastName
                  : userData.firstName,
              textAlign: TextAlign.left,
              maxLines: 1,
              style: TextStyle(
                fontWeight: FontWeight.w500,
                color: Colors.black,
                fontSize: ScreenUtil().setSp(15),
                fontFamily: 'Rubik',
              ),
            ),
          ),
          Container(
            width: ScreenUtil().setWidth(250),
            margin: EdgeInsets.only(
              left: ScreenUtil().setWidth(10.0),
            ),
            child: Text(
              userData.about != null && userData.about != "null"
                  ? userData.about
                  : "",
              textAlign: TextAlign.left,
              maxLines: 1,
              style: TextStyle(
                fontWeight: FontWeight.normal,
                color: Color(0xff98A9BC),
                fontSize: ScreenUtil().setSp(13),
                fontFamily: "Rubik",
              ),
            ),
          ),
          Container(
            margin: EdgeInsets.only(
              left: ScreenUtil().setWidth(10.0),
            ),
            child: Text(
              timeago.format(fifteenAgo, locale: 'en_short'),
              style: TextStyle(
                color: Color(0xff98A9BC),
              ),
            ),
          )
        ],
      ),
    );
  }

  _buildMoreIcon() {
    return Container(
        padding: EdgeInsets.only(left: ScreenUtil().setWidth(10)),
        alignment: Alignment.centerLeft,
        child: IconButton(
          icon: Icon(Icons.more_vert),
          iconSize: 35,
          onPressed: () {
            showModalBottomSheet(
              context: context,
              builder: (context) {
                return Directionality(
                  textDirection: TextDirection.ltr,
                  child: Wrap(
                    children: [
                      ListTile(
                        leading: Icon(
                          Icons.bookmarks_outlined,
                          color: Colors.black,
                        ),
                        title: mySave
                            ? Text(
                                this.widget.loc.translate(
                                    'Cancel saving this item for later'),
                              )
                            : Text(
                                this
                                    .widget
                                    .loc
                                    .translate('Save this item for later'),
                              ),
                        onTap: () {
                          setState(() {
                            mySave = !mySave;
                          });
                          if (mySave) {
                            Navigator.of(context).pop();
                            show();
                          } else {
                            Navigator.of(context).pop();
                            removeReportPost(reportSaveId, this.widget.saveId);
                          }
                        },
                      ),
                      ListTile(
                        leading: Icon(
                          Icons.share_outlined,
                          color: Colors.black,
                        ),
                        title: Text(this.widget.loc.translate('Share via')),
                        onTap: () {
                          var post = this.widget.postData;
                          Navigator.of(context).pop();
                          share(post.title, post.description, post.attachedUrl,
                              userData);
                        },
                      ),
                      ListTile(
                        leading: Icon(
                          Icons.cancel,
                          color: Colors.black,
                        ),
                        title: Text(
                            this.widget.loc.translate('Unfollow Janet Doe')),
                      ),
                      ListTile(
                        onTap: flagReport == true || flagReport == null
                            ? () {
                                showDialog(
                                  context: context,
                                  builder: (BuildContext context) {
                                    return Reports(
                                      loc: this.widget.loc,
                                      currentUser: this.widget.currentUser,
                                      postData: this.widget.postData,
                                    );
                                  },
                                ).then((value) => {
                                      setState(() {
                                        flagReport = value;
                                      }),
                                      Navigator.of(context).pop()
                                    });
                              }
                            : null,
                        leading: flagReport == true || flagReport == null
                            ? Icon(
                                Icons.outlined_flag_rounded,
                                color: Colors.black,
                              )
                            : Icon(
                                Icons.outlined_flag_rounded,
                                color: Colors.grey,
                              ),
                        title: flagReport == true || flagReport == null
                            ? Text(this.widget.loc.translate('Report the post'))
                            : Text(
                                this.widget.loc.translate('Report the post'),
                                style: TextStyle(color: Colors.grey),
                              ),
                      ),
                      widget.postData.user.id == widget.currentUser.id
                          ? ListTile(
                              leading: Icon(
                                Icons.delete_outline,
                                color: Colors.black,
                              ),
                              title: Text(
                                  this.widget.loc.translate('Delete post')),
                              onTap: () async {
                                await removeUserPost();
                              },
                            )
                          : Container(),
                    ],
                  ),
                );
              },
            );
          },
        ));
  }

  _buildPostText() {
    return GestureDetector(
      onTap: () async {
        var result = await Navigator.push(
          context,
          new MaterialPageRoute(
            builder: (BuildContext context) => new ChatScreen(
              currentUser: this.widget.currentUser,
              senderName: this.widget.currentUser.firstName +
                  " " +
                  this.widget.currentUser.lastName,
              about: this.widget.currentUser.about,
              senderImage: this.widget.currentUser.profileImg,
              post: FeedPost(
                postData: this.widget.postData,
                currentUser: this.widget.currentUser,
                likeId: this.widget.likeId,
                saveId: this.widget.saveId,
                dislikeId: this.widget.dislikeId,
                images: this.widget.images,
                commentsLength: this.widget.commentsLength,
                postsList: this.widget.postsList,
                pollOptionsList: this.widget.pollOptionsList,
                generalPollOptionsList: this.widget.generalPollOptionsList,
                pollVotesList: pollVotesList,
                loc: this.widget.loc,
              ),
              postsList: this.widget.postsList,
              pollOptionsList: this.widget.pollOptionsList,
              loc: this.widget.loc,
              pollVotesList: pollVotesList,
            ),
          ),
        );
        if (widget.postData.pollQuestion != null) {
          setState(() {
            loadPoll();
          });
        }
      },
      child: Column(
        children: [
          Container(
            margin: EdgeInsets.only(
              top: ScreenUtil().setWidth(10),
              left: ScreenUtil().setWidth(17.0),
              right: ScreenUtil().setWidth(17.0),
            ),
            width: ScreenUtil().screenWidth,
            child: buildParsedText(
                widget.postData.title + " ",
                TextStyle(
                    fontSize: ScreenUtil().setSp(15),
                    fontFamily: 'Rubik',
                    color: Colors.black,
                    fontWeight: FontWeight.w600)),
          ),
          Container(
            padding: EdgeInsets.only(
              top: ScreenUtil().setWidth(7),
              left: ScreenUtil().setWidth(17),
              right: ScreenUtil().setWidth(17),
            ),
            width: ScreenUtil().screenWidth,
            child: secondHalf.isEmpty
                ? buildParsedText(
                    firstHalf,
                    TextStyle(
                        fontSize: ScreenUtil().setSp(15),
                        fontFamily: 'Rubik',
                        color: Colors.black))
                : new Column(
                    children: <Widget>[
                      buildParsedText(
                          flag ? (firstHalf + "...") : (firstHalf + secondHalf),
                          TextStyle(
                              fontSize: ScreenUtil().setSp(15),
                              fontFamily: 'Rubik',
                              color: Colors.black)),
                      new InkWell(
                        child: new Row(
                          mainAxisAlignment: MainAxisAlignment.end,
                          children: <Widget>[
                            Expanded(
                              child: Padding(
                                padding: const EdgeInsets.only(right: 7),
                                child: new Text(
                                  flag
                                      ? this.widget.loc.translate("see more")
                                      : this.widget.loc.translate("see less"),
                                  style: new TextStyle(color: Colors.blue),
                                ),
                              ),
                            ),
                          ],
                        ),
                        onTap: () {
                          setState(() {
                            flag = !flag;
                          });
                        },
                      ),
                    ],
                  ),
          ),
          // widget.pollOptionsList != null &&
          //         widget.pollOptionsList.length > 0 &&
          //         widget.postData.pollQuestion != null
          //     ? isPollResult == true
          //         ? _buildPollResult()
          //         : _buildPollQuestion()
          //     : Text(""),
        ],
      ),
    );
  }

  _buildPoll() {
    return widget.pollOptionsList != null &&
            widget.pollOptionsList.length > 0 &&
            widget.postData.pollQuestion != null
        ? isPollResult == true
            ? _buildPollResult()
            : _buildPollQuestion()
        : Text("");
  }

  _buildPostAttached() {
    return Container(
        margin: EdgeInsets.only(top: ScreenUtil().setWidth(5)),
        child: this.widget.postData.type == "Photo"
            ? this.widget.images.length > 1
                ? Container(
                    color: Colors.grey[200],
                    height: widget.images.length == 2
                        ? ScreenUtil().setHeight(200)
                        : ScreenUtil().setHeight(410),
                    child: PhotoGrid(
                      imageUrls: widget.images,
                      onImageClicked: (i) => {
                        print('Image $i was clicked!'),
                        Navigator.push(
                            context,
                            MaterialPageRoute(
                              builder: (context) => VideoAndPicture(
                                  image: this.widget.images[i],
                                  title: this.widget.postData.title),
                            )),
                      },
                      onExpandClicked: () => print('Expand Image was clicked'),
                      maxImages: 4,
                    ))
                : GestureDetector(
                    onTap: () {
                      Navigator.push(
                        context,
                        MaterialPageRoute(
                          builder: (context) => VideoAndPicture(
                              image: this.widget.postData.attachedUrl,
                              title: this.widget.postData.title),
                        ),
                      );
                    },
                    child: Container(
                        child: Image.network(
                      this.widget.postData.attachedUrl,
                      fit: BoxFit.cover,
                    )))
            : this.widget.postData.type == "Video"
                ? Container(
                    height: ScreenUtil().setHeight(500),
                    padding: EdgeInsets.only(
                        top: ScreenUtil().setHeight(2),
                        bottom: ScreenUtil().setHeight(2)),
                    color: Colors.grey[100],
                    child: VideoB(
                        withControls: true,
                        volume: 0.0,
                        url: this.widget.postData.attachedUrl,
                        play: widget.play))
                : Container());
  }

  _buildShowComments() {
    return Container(
      alignment: Alignment.centerLeft,
      width: ScreenUtil().setWidth(175),
      margin: EdgeInsets.only(
        top: ScreenUtil().setWidth(8),
        bottom: ScreenUtil().setWidth(8),
      ),
      child: GestureDetector(
        onTap: () async {
          var result = await Navigator.push(
            context,
            new MaterialPageRoute(
              builder: (BuildContext context) => new ChatScreen(
                currentUser: this.widget.currentUser,
                senderName: this.widget.currentUser.firstName +
                    " " +
                    this.widget.currentUser.lastName,
                about: this.widget.currentUser.about,
                senderImage: this.widget.currentUser.profileImg,
                post: FeedPost(
                  postData: this.widget.postData,
                  currentUser: this.widget.currentUser,
                  likeId: this.widget.likeId,
                  saveId: this.widget.saveId,
                  dislikeId: this.widget.dislikeId,
                  images: this.widget.images,
                  commentsLength: this.widget.commentsLength,
                  postsList: this.widget.postsList,
                  pollOptionsList: this.widget.pollOptionsList,
                  generalPollOptionsList: this.widget.generalPollOptionsList,
                  pollVotesList: pollVotesList,
                  loc: this.widget.loc,
                ),
                postsList: this.widget.postsList,
                pollOptionsList: this.widget.pollOptionsList,
                loc: this.widget.loc,
                pollVotesList: pollVotesList,
              ),
            ),
          );
          if (widget.postData.pollQuestion != null) {
            setState(() {
              loadPoll();
            });
          }
          if (mounted) {
            setState(() {
              if (result.commentsLength > 0) {
                commentsOnPost = result.commentsLength;
              } else if (result.commentsLength == -1) {
                commentsOnPost = 0;
              }
              getLikesListByPostId(result.postData.id);
            });
          }
        },
        child: this.widget.commentsLength > 0
            ? Text(
                this.widget.loc.translate("Show all ") +
                    display(this.widget.commentsLength) +
                    this.widget.loc.translate(" comments"),
                style: TextStyle(
                    fontSize: ScreenUtil().setSp(13), color: Color(0xff98A9BC)),
              )
            : this.widget.commentsLength == -1
                ? Text("")
                : this.commentsOnPost > 0
                    ? Text(
                        this.widget.loc.translate("Show all ") +
                            display(commentsOnPost) +
                            this.widget.loc.translate(" comments"),
                        style: TextStyle(
                            fontSize: ScreenUtil().setSp(13),
                            color: Color(0xff98A9BC)),
                      )
                    : Text(""),
      ),
    );
  }

  _buildShowLikes() {
    return Container(
      alignment: Alignment.centerRight,
      width: ScreenUtil().setWidth(180),
      child: GestureDetector(
        onTap: () {
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => LikesAndDislikes(
                  loc: this.widget.loc,
                  likesList: likesList,
                  dislikesList: dislikesList,
                  postTitle: this.widget.postData.title),
            ),
          );
        },
        child: likesList.length + dislikesList.length > 0
            ? Text(
                this.widget.loc.translate("Show ") +
                    display(likesList.length + dislikesList.length) +
                    this.widget.loc.translate(" Likes&Dislikes"),
                style: TextStyle(
                    fontSize: ScreenUtil().setSp(13), color: Color(0xff98A9BC)),
              )
            : Text(""),
      ),
    );
  }

  _buildButtomBar() {
    return Container(
      child: Row(
        children: [
          Expanded(
              child: Column(children: [
            IconButton(
              icon: myLike
                  ? Icon(Icons.thumb_up, color: Colors.green)
                  : Icon(Icons.thumb_up_off_alt, color: Colors.black),
              onPressed: myDislike
                  ? null
                  : () {
                      setState(
                        () {
                          myLike = !myLike;
                          if (myLike) {
                            reportPost(this.widget.likeId);
                            if (myDislike) {
                              myDislike = false;
                              removeReportPost(
                                  reportDislikeId, this.widget.dislikeId);
                            }
                          } else {
                            removeReportPost(reportLikeId, this.widget.likeId);
                          }
                        },
                      );
                    },
            ),
            Text(
              this.widget.loc.translate("Like"),
              style: TextStyle(fontSize: ScreenUtil().setSp(12)),
            )
          ])),
          Expanded(
            child: Column(children: [
              IconButton(
                icon: myDislike
                    ? Icon(Icons.thumb_down, color: Colors.red)
                    : Icon(
                        Icons.thumb_down_off_alt,
                        color: Colors.black,
                      ),
                onPressed: myLike
                    ? null
                    : () {
                        setState(
                          () {
                            myDislike = !myDislike;
                            if (myDislike) {
                              reportPost(this.widget.dislikeId);
                              if (myLike) {
                                myLike = false;
                                removeReportPost(
                                    reportLikeId, this.widget.likeId);
                              }
                            } else {
                              removeReportPost(
                                  reportDislikeId, this.widget.dislikeId);
                            }
                          },
                        );
                      },
              ),
              Text(
                this.widget.loc.translate("Dislike"),
                style: TextStyle(fontSize: ScreenUtil().setSp(12)),
              )
            ]),
          ),
          Expanded(
            child: Column(
              children: [
                IconButton(
                    icon: Icon(
                      Icons.messenger_outline,
                      color: Colors.black,
                    ),
                    onPressed: () async {
                      var result = await Navigator.push(
                        context,
                        new MaterialPageRoute(
                          builder: (BuildContext context) => new ChatScreen(
                            currentUser: this.widget.currentUser,
                            senderName: this.widget.currentUser.firstName +
                                " " +
                                this.widget.currentUser.lastName,
                            about: this.widget.currentUser.about,
                            senderImage: this.widget.currentUser.profileImg,
                            post: FeedPost(
                              postData: this.widget.postData,
                              currentUser: this.widget.currentUser,
                              likeId: this.widget.likeId,
                              saveId: this.widget.saveId,
                              dislikeId: this.widget.dislikeId,
                              images: this.widget.images,
                              commentsLength: this.widget.commentsLength,
                              postsList: this.widget.postsList,
                              pollOptionsList: this.widget.pollOptionsList,
                              generalPollOptionsList:
                                  this.widget.generalPollOptionsList,
                              pollVotesList: pollVotesList,
                              loc: this.widget.loc,
                            ),
                            postsList: this.widget.postsList,
                            pollOptionsList: this.widget.pollOptionsList,
                            loc: this.widget.loc,
                            pollVotesList: pollVotesList,
                          ),
                        ),
                      );
                      if (widget.postData.pollQuestion != null) {
                        setState(() {
                          loadPoll();
                        });
                      }

                      setState(() {
                        if (result.commentsLength > 0) {
                          commentsOnPost = result.commentsLength;
                        } else if (result.commentsLength == -1) {
                          commentsOnPost = 0;
                        }
                        getLikesListByPostId(result.postData.id);
                      });
                    }),
                Text(
                  this.widget.loc.translate("Comments"),
                  style: TextStyle(
                    fontSize: ScreenUtil().setSp(12),
                  ),
                )
              ],
            ),
          ),
          Expanded(
              child: Column(children: [
            TextButton(
              child: Icon(
                Icons.share_outlined,
                color: Colors.black,
              ),
              onPressed: () {
                share(
                    this.widget.postData.title,
                    this.widget.postData.description,
                    this.widget.postData.attachedUrl,
                    userData);
              },
            ),
            Text(
              this.widget.loc.translate("Share"),
              style: TextStyle(fontSize: ScreenUtil().setSp(12)),
            )
          ])),
          Expanded(
            child: Column(
              children: [
                IconButton(
                    icon: Icon(
                      mySave ? Icons.favorite : Icons.favorite_outline,
                      color: mySave ? Colors.pink : Colors.black,
                    ),
                    onPressed: () {
                      setState(() {
                        mySave = !mySave;
                      });
                      mySave
                          ? show()
                          : removeReportPost(reportSaveId, this.widget.saveId);
                    }),
                Text(
                  this.widget.loc.translate("Save"),
                  style: TextStyle(fontSize: ScreenUtil().setSp(12)),
                )
              ],
            ),
          ),
        ],
      ),
    );
  }

  _buildOptionButton({@required PollOptionModel optionData}) {
    return SizedBox(
      width: double.infinity,
      // ignore: deprecated_member_use
      child: FlatButton(
        splashColor: Colors.lightBlue[100],
        shape: RoundedRectangleBorder(
          borderRadius: new BorderRadius.circular(25),
          side: BorderSide(color: Colors.blue),
        ),
        onPressed: _clicked
            ? null
            : () {
                setState(() => _clicked = true);
                if (voteToRemove == null) {
                  feedRepository
                      .createPollVote(optionData.id, this.widget.currentUser.id)
                      .then((value) => {
                            setState(() {
                              voteToRemove = value;
                              if (optionData.id ==
                                  widget.pollOptionsList[0].id) {
                                pollOptions1VotesListLength++;
                                pollOptions1VotesList.add(voteToRemove);
                              } else if (optionData.id ==
                                  widget.pollOptionsList[1].id) {
                                pollOptions2VotesList.add(voteToRemove);
                                pollOptions2VotesListLength++;
                              } else if (widget.pollOptionsList.length > 2) {
                                if (optionData.id ==
                                    widget.pollOptionsList[2].id) {
                                  pollOptions3VotesListLength++;

                                  pollOptions3VotesList.add(voteToRemove);
                                } else {
                                  if (widget.pollOptionsList.length > 3) {
                                    if (optionData.id ==
                                        widget.pollOptionsList[3].id) {
                                      pollOptions4VotesListLength++;
                                      pollOptions4VotesList.add(voteToRemove);
                                    }
                                  }
                                }
                              }

                              isPollResult = true;

                              pollVotesList.add(value);
                              pollVotesListLength++;
                            })
                          });
                }
              },
        child: Text(
          optionData.option,
          style: TextStyle(
            color: Colors.blue,
          ),
        ),
      ),
    );
  }

  _buildPollResult() {
    return Padding(
      padding: EdgeInsets.all(
        ScreenUtil().setHeight(20),
      ),
      child: Container(
        width: ScreenUtil().screenWidth - ScreenUtil().setHeight(20),
        decoration: BoxDecoration(
          border: Border.all(
            color: Colors.grey,
          ),
          borderRadius: new BorderRadius.circular(5),
        ),
        child: Padding(
          padding: EdgeInsets.all(
            ScreenUtil().setHeight(8),
          ),
          child: Column(
            children: [
              Text(
                this.widget.postData.pollQuestion.question,
                style: TextStyle(fontWeight: FontWeight.bold),
              ),
              _buildOption(
                  option: this.widget.pollOptionsList[0],
                  votesLength: pollOptions1VotesList.length),
              _buildOption(
                  option: this.widget.pollOptionsList[1],
                  votesLength: pollOptions2VotesList.length),
              widget.pollOptionsList.length > 2
                  ? Visibility(
                      child: _buildOption(
                          option: this.widget.pollOptionsList[2],
                          votesLength: pollOptions3VotesList.length),
                      visible: this.widget.pollOptionsList[2].option != "" ||
                          this.widget.pollOptionsList[2].option != null,
                    )
                  : Container(),
              widget.pollOptionsList.length > 3
                  ? Visibility(
                      child: _buildOption(
                          option: this.widget.pollOptionsList[3],
                          votesLength: pollOptions4VotesList.length),
                      visible: this.widget.pollOptionsList[3].option != "" ||
                          this.widget.pollOptionsList[3].option != null,
                    )
                  : Container(),
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Row(
                    children: [
                      this.widget.postData.user.id ==
                                  this.widget.currentUser.id &&
                              pollVotesList.length > 0
                          // ignore: deprecated_member_use
                          ? FlatButton(
                              child: Text(
                                (pollOptions1VotesList.length +
                                            pollOptions2VotesList.length +
                                            pollOptions3VotesList.length +
                                            pollOptions4VotesList.length)
                                        .toString() +
                                    " " +
                                    widget.loc.translate('votes'),
                              ),
                              onPressed: () {
                                setState(() => _clicked = false);
                                Navigator.push(
                                  context,
                                  MaterialPageRoute(
                                    builder: (context) => VotesPage(
                                      pollOptions1VotesList:
                                          pollOptions1VotesList,
                                      pollOptions2VotesList:
                                          pollOptions2VotesList,
                                      pollOptions3VotesList:
                                          pollOptions3VotesList,
                                      pollOptions4VotesList:
                                          pollOptions4VotesList,
                                      pollOption1:
                                          this.widget.pollOptionsList[0].option,
                                      pollOption2:
                                          this.widget.pollOptionsList[1].option,
                                      pollOption3:
                                          this.widget.pollOptionsList.length > 2
                                              ? this
                                                  .widget
                                                  .pollOptionsList[2]
                                                  .option
                                              : null,
                                      pollOption4:
                                          this.widget.pollOptionsList.length > 3
                                              ? this
                                                  .widget
                                                  .pollOptionsList[3]
                                                  .option
                                              : null,
                                      loc: this.widget.loc,
                                    ),
                                  ),
                                );
                              },
                            )
                          : Text(
                              (pollOptions1VotesList.length +
                                          pollOptions2VotesList.length +
                                          pollOptions3VotesList.length +
                                          pollOptions4VotesList.length)
                                      .toString() +
                                  " " +
                                  widget.loc.translate('votes'),
                            ),
                      voteToRemove != null
                          // ignore: deprecated_member_use
                          ? FlatButton(
                              child: Text(widget.loc.translate('Undo')),
                              onPressed: () {
                                setState(() => _clicked = false);
                                removePollVote(voteToRemove: voteToRemove)
                                    .then((value) => {
                                          if (value == true)
                                            {
                                              setState(() {
                                                isPollResult = false;
                                                pollVotesList
                                                    .remove(voteToRemove);

                                                pollVotesListLength--;

                                                if (pollVotesListLength < 0) {
                                                  pollVotesListLength = 0;
                                                }

                                                if (voteToRemove
                                                        .pollOption.id ==
                                                    widget.pollOptionsList[0]
                                                        .id) {
                                                  pollOptions1VotesList
                                                      .remove(voteToRemove);
                                                  pollOptions1VotesListLength--;
                                                  if (pollOptions1VotesListLength <
                                                      0) {
                                                    pollOptions1VotesListLength =
                                                        0;
                                                  }
                                                } else if (voteToRemove
                                                        .pollOption.id ==
                                                    widget.pollOptionsList[1]
                                                        .id) {
                                                  pollOptions2VotesList
                                                      .remove(voteToRemove);

                                                  pollOptions2VotesListLength--;
                                                  if (pollOptions2VotesListLength <
                                                      0) {
                                                    pollOptions2VotesListLength =
                                                        0;
                                                  }
                                                } else if (this
                                                        .widget
                                                        .pollOptionsList
                                                        .length >
                                                    2) {
                                                  if (voteToRemove
                                                          .pollOption.id ==
                                                      widget.pollOptionsList[2]
                                                          .id) {
                                                    pollOptions3VotesList
                                                        .remove(voteToRemove);
                                                    pollOptions3VotesListLength--;
                                                    if (pollOptions3VotesListLength <
                                                        0) {
                                                      pollOptions3VotesListLength =
                                                          0;
                                                    }
                                                  }
                                                } else if (this
                                                        .widget
                                                        .pollOptionsList
                                                        .length >
                                                    3) {
                                                  if (voteToRemove
                                                          .pollOption.id ==
                                                      widget.pollOptionsList[3]
                                                          .id) {
                                                    pollOptions4VotesList
                                                        .remove(voteToRemove);
                                                    pollOptions4VotesListLength--;
                                                    if (pollOptions4VotesListLength <
                                                        0) {
                                                      pollOptions4VotesListLength =
                                                          0;
                                                    }
                                                  }
                                                }
                                                voteToRemove = null;
                                              })
                                            }
                                        });
                              },
                            )
                          : Text(""),
                    ],
                  ),
                  this.widget.postData.user.id == this.widget.currentUser.id
                      // ignore: deprecated_member_use
                      ? FlatButton(
                          child: Text(
                            widget.loc.translate('Hide results'),
                          ),
                          onPressed: () {
                            setState(() {
                              isPollResult = false;
                            });
                          },
                        )
                      : Text(""),
                ],
              ),
            ],
          ),
        ),
      ),
    );
  }

  _buildPollQuestion() {
    var res = checkIsHebrew(widget.postData.pollQuestion.question);
    return Padding(
      padding: EdgeInsets.all(
        ScreenUtil().setHeight(20),
      ),
      child: Container(
        width: ScreenUtil().screenWidth - ScreenUtil().setHeight(20),
        decoration: BoxDecoration(
          border: Border.all(
            color: Colors.grey,
          ),
          borderRadius: new BorderRadius.circular(5),
        ),
        child: Padding(
          padding: EdgeInsets.all(
            ScreenUtil().setHeight(8),
          ),
          child: Column(
            children: [
              Text(
                this.widget.postData.pollQuestion.question,
                textAlign: res ? TextAlign.end : TextAlign.start,
                style: TextStyle(fontWeight: FontWeight.bold),
              ),
              _buildOptionButton(optionData: this.widget.pollOptionsList[0]),
              _buildOptionButton(optionData: this.widget.pollOptionsList[1]),
              widget.pollOptionsList.length > 2
                  ? Visibility(
                      child: _buildOptionButton(
                          optionData: this.widget.pollOptionsList[2]),
                      visible: this.widget.pollOptionsList[2].option != "" ||
                          this.widget.pollOptionsList[2].option != null,
                    )
                  : Container(),
              widget.pollOptionsList.length > 3
                  ? Visibility(
                      child: _buildOptionButton(
                          optionData: this.widget.pollOptionsList[3]),
                      visible: this.widget.pollOptionsList[3].option != "" ||
                          this.widget.pollOptionsList[3].option != null,
                    )
                  : Container(),
              Row(
                children: [
                  this.widget.postData.user.id == this.widget.currentUser.id &&
                          pollVotesListLength > 0
                      ? FlatButton(
                          child: Text(
                            (pollOptions1VotesList.length +
                                        pollOptions2VotesList.length +
                                        pollOptions3VotesList.length +
                                        pollOptions4VotesList.length)
                                    .toString() +
                                " " +
                                widget.loc.translate('votes'),
                          ),
                          onPressed: () {
                            Navigator.push(
                              context,
                              MaterialPageRoute(
                                builder: (context) => VotesPage(
                                  pollOptions1VotesList: pollOptions1VotesList,
                                  pollOptions2VotesList: pollOptions2VotesList,
                                  pollOptions3VotesList: pollOptions3VotesList,
                                  pollOptions4VotesList: pollOptions4VotesList,
                                  pollOption1:
                                      this.widget.pollOptionsList[0].option,
                                  pollOption2:
                                      this.widget.pollOptionsList[1].option,
                                  pollOption3:
                                      this.widget.pollOptionsList.length > 2
                                          ? this
                                              .widget
                                              .pollOptionsList[2]
                                              .option
                                          : null,
                                  pollOption4:
                                      this.widget.pollOptionsList.length > 3
                                          ? this
                                              .widget
                                              .pollOptionsList[3]
                                              .option
                                          : null,
                                  loc: this.widget.loc,
                                ),
                              ),
                            );
                          },
                        )
                      : Text(
                          (pollOptions1VotesList.length +
                                      pollOptions2VotesList.length +
                                      pollOptions3VotesList.length +
                                      pollOptions4VotesList.length)
                                  .toString() +
                              " " +
                              widget.loc.translate('votes'),
                        ),
                  this.widget.postData.user.id == this.widget.currentUser.id &&
                          pollVotesListLength > 0
                      // ignore: deprecated_member_use
                      ? FlatButton(
                          child: Text(
                            widget.loc.translate('View results'),
                          ),
                          onPressed: () {
                            setState(() {
                              isPollResult = true;
                              pollOptions1VotesList = [];
                              pollOptions2VotesList = [];
                              pollOptions3VotesList = [];
                              pollOptions4VotesList = [];
                              for (var i = 0; i < pollVotesList.length; i++) {
                                if (pollVotesList[i].pollOption.id ==
                                    widget.pollOptionsList[0].id) {
                                  pollOptions1VotesList.add(pollVotesList[i]);
                                } else if (pollVotesList[i].pollOption.id ==
                                    widget.pollOptionsList[1].id) {
                                  pollOptions2VotesList.add(pollVotesList[i]);
                                } else if (widget.pollOptionsList.length > 2) {
                                  if (pollVotesList[i].pollOption.id ==
                                      widget.pollOptionsList[2].id) {
                                    pollOptions3VotesList.add(pollVotesList[i]);
                                  }
                                } else if (widget.pollOptionsList.length > 3) {
                                  if (pollVotesList[i].pollOption.id ==
                                      widget.pollOptionsList[3].id) {
                                    pollOptions4VotesList.add(pollVotesList[i]);
                                  }
                                }
                              }
                            });
                          },
                        )
                      : Text(""),
                ],
              ),
            ],
          ),
        ),
      ),
    );
  }

  _buildOption({@required PollOptionModel option, @required int votesLength}) {
    int denominator = pollOptions1VotesList.length +
        pollOptions2VotesList.length +
        pollOptions3VotesList.length +
        pollOptions4VotesList.length;
    denominator == 0 ? denominator = 1 : denominator = denominator;

    var thisPercent = ((votesLength / (denominator)) * 100).toInt();
    var strPercent = thisPercent.toString() + "%";
    setState(() {
      percent.add(strPercent);
    });
    return Padding(
      padding: const EdgeInsets.all(4.0),
      child: Stack(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Expanded(
                child: Container(
                  decoration: BoxDecoration(
                    borderRadius: new BorderRadius.circular(3),
                    color: votesLength > 0 ? Colors.grey[300] : Colors.white,
                  ),
                  child: Padding(
                    padding: const EdgeInsets.all(8.0),
                    child: Text(""),
                  ),
                ),
                flex: thisPercent,
              ),
              Expanded(
                  child: Directionality(
                    textDirection: TextDirection.rtl,
                    child: Text(
                      "",
                    ),
                  ),
                  flex: 100 - thisPercent),
            ],
          ),
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Flexible(
                  fit: FlexFit.loose,
                  child: Text(
                    option.option,
                    softWrap: false,
                    overflow: TextOverflow.ellipsis,
                  ),
                ),
                Container(
                  margin: EdgeInsets.only(left: 16),
                  child: voteToRemove != null
                      ? voteToRemove.pollOption.id == option.id
                          ? Icon(
                              Icons.check_circle_rounded,
                              color: Colors.grey,
                            )
                          : Text("")
                      : Text(""),
                ),
                Align(
                  alignment: Alignment.centerRight,
                  child: Text(
                    strPercent,
                    style: TextStyle(fontWeight: FontWeight.bold),
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }

  Future<bool> removePollVote({PollVoteModel voteToRemove}) async {
    bool isSuccess = await feedRepository.removePollVote(voteToRemove.id);
    return isSuccess;
  }

  loadPoll() async {
    await _loadVotes();

    pollOptions1VotesList = [];
    pollOptions2VotesList = [];
    pollOptions3VotesList = [];
    pollOptions4VotesList = [];

    for (var i = 0; i < pollVotesList.length; i++) {
      if (pollVotesList[i].pollOption.id == widget.pollOptionsList[0].id) {
        pollOptions1VotesList.add(pollVotesList[i]);
      } else if (pollVotesList[i].pollOption.id ==
          widget.pollOptionsList[1].id) {
        pollOptions2VotesList.add(pollVotesList[i]);
      } else if (widget.pollOptionsList.length > 2) {
        if (pollVotesList[i].pollOption.id == widget.pollOptionsList[2].id) {
          pollOptions3VotesList.add(pollVotesList[i]);
        }
        if (widget.pollOptionsList.length > 3) {
          if (pollVotesList[i].pollOption.id == widget.pollOptionsList[3].id) {
            pollOptions4VotesList.add(pollVotesList[i]);
          }
        }
      }
    }
    setState(() {
      voteToRemove = pollVotesList.firstWhere(
          (item) => item.user.id == this.widget.currentUser.id,
          orElse: () => null);
      isPollResult = voteToRemove == null ? false : true;
    });
  }

  _loadVotes() async {
    return await feedRepository.getAllVotes().then((value) async => {
          setState(() {
            pollVotesList = value;
          })
        });
  }

  buildParsedText(String myText, TextStyle style) {
    bool res;
    res = checkIsHebrew(myText);
    return ParsedText(
      alignment: res ? TextAlign.end : TextAlign.start,
      text: myText,
      parse: <MatchText>[
        MatchText(
            type: ParsedType.EMAIL,
            style: TextStyle(
              color: Colors.blue,
              fontSize: ScreenUtil().setSp(15),
            ),
            onTap: (url) {
              launch("mailto:" + url);
            }),
        MatchText(
            type: ParsedType.URL,
            style: TextStyle(
              color: Colors.blue,
              fontSize: ScreenUtil().setSp(15),
            ),
            onTap: (url) async {
              var a = await canLaunch(url);

              if (a) {
                launch(url);
              }
            }),
        MatchText(
            type: ParsedType.PHONE,
            style: TextStyle(
              color: Colors.blue,
              fontSize: ScreenUtil().setSp(15),
            ),
            onTap: (url) {
              launch("tel:" + url);
            }),
        MatchText(
            pattern: r"\B#+([\w]+)\b",
            style: TextStyle(
              color: Colors.blue,
              fontSize: ScreenUtil().setSp(15),
            ),
            onTap: (url) async {
              feedRepository
                  .getHashtagPostByTagName(url.toString())
                  .then((value) async => {
                        FutureBuilder(
                            future: await Navigator.push(
                              context,
                              new MaterialPageRoute(
                                builder: (context) => HashtagPosts(
                                  hashtagPostsData: value,
                                  loc: widget.loc,
                                  currentUser: widget.currentUser,
                                  pollOptionsList: this.widget.pollOptionsList,
                                  pollVotesList: pollVotesList,
                                ),
                              ),
                            ).then((value) => loadPoll()),
                            builder:
                                (context, AsyncSnapshot<dynamic> snapshot) {
                              if (snapshot.connectionState ==
                                      ConnectionState.waiting ||
                                  snapshot.hasError) {
                                return CircularProgressIndicator();
                              }
                              return Container();
                            })
                      });
            }),
        MatchText(
            pattern: r"lon",
            style: TextStyle(
              color: Colors.blue,
              fontSize: ScreenUtil().setSp(15),
            ),
            onTap: (url) async {})
      ],
      style: style,
    );
  }
}
