import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:video_player/video_player.dart';

import 'chewie/chewie_player.dart';

class VideoB extends StatefulWidget {
  const VideoB(
      {Key key,
      @required this.volume,
      @required this.url,
      @required this.play,
      @required this.withControls,
      this.title = 'Chewie Demo'})
      : super();

  final String url;
  final String title;
  final bool play;
  final bool withControls;
  final double volume;

  @override
  State<StatefulWidget> createState() {
    return _VideoBState();
  }
}

class _VideoBState extends State<VideoB> {
  VideoPlayerController _videoPlayerController1;
  VideoPlayerController _videoPlayerController2;
  ChewieController _chewieController;

  @override
  void initState() {
    super.initState();
    initializePlayer();
  }

  @override
  void dispose() {
    _videoPlayerController1?.dispose();
    _videoPlayerController2?.dispose();
    _chewieController?.dispose();
    super.dispose();
  }

  Future<void> initializePlayer() async {
    _videoPlayerController1 = VideoPlayerController.network(this.widget.url);
    _videoPlayerController1.initialize().then((value) => {
          _chewieController = ChewieController(
            videoPlayerController: _videoPlayerController1,
            autoPlay: true,
            looping: true,
            autoInitialize: true,
            placeholder: Container(
              height: ScreenUtil().setHeight(570),
              padding: EdgeInsets.only(
                  top: ScreenUtil().setHeight(5),
                  bottom: ScreenUtil().setHeight(5)),
              color: Colors.grey[100],
            ),
          )..setVolume(widget.volume),
          if (widget.play != null && widget.play && _chewieController != null)
            {_chewieController.play(), _chewieController.setLooping(true)}
          else
            {_chewieController?.pause()},
          setState(() {})
        });
  }

  @override
  void didUpdateWidget(VideoB oldWidget) {
    if (oldWidget?.play != widget.play) {
      if (widget.play) {
        _chewieController?.play();
        _chewieController?.setLooping(true);
      } else {
        _chewieController?.pause();
      }
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return Center(
      child: _chewieController != null &&
              _chewieController.videoPlayerController.value.isInitialized
          ? Chewie(
              controller: _chewieController,
              withControls: widget.withControls,
            )
          : Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: const [
                CircularProgressIndicator(),
                SizedBox(height: 20),
                Text('Loading'),
              ],
            ),
    );
  }
}